package org.jeecg.modules.admincasehistory.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.aliyun.ocr_api20210707.models.RecognizeAdvancedResponse;
import com.aliyun.tea.TeaException;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import net.sf.json.JSONObject;
import org.apache.catalina.security.SecurityUtil;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.admincasehistory.entity.AdminMedicalHistory;
import org.jeecg.modules.admincasehistory.service.IAdminMedicalHistoryService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.adminuser.entity.AdminCompSelect;
import org.jeecg.modules.adminuser.entity.AdminUser;
import org.jeecg.modules.adminuser.service.IAdminCompSelectService;
import org.jeecg.modules.adminuser.service.IAdminUserService;
import org.jeecg.modules.api.entity.ORCPicUrl;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

/**
 * @Description: 病历管理
 * @Author: jeecg-boot
 * @Date: 2022-12-22
 * @Version: V1.0
 */
@Api(tags = "病历管理")
@RestController
@RequestMapping("/admincasehistory/adminMedicalHistory")
@Slf4j
public class AdminMedicalHistoryController extends JeecgController<AdminMedicalHistory, IAdminMedicalHistoryService> {
    @Autowired
    private IAdminMedicalHistoryService adminMedicalHistoryService;
    @Autowired
    private IAdminUserService adminUserService;
    @Autowired
    private ISysUserService sysUserService;
    @Autowired
    private IAdminCompSelectService adminCompSelectService;

    @Value("${jeecg.path.upload}")
    private String upLoadPath;

    /**
     * 分页列表查询
     *
     * @param adminMedicalHistory
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */

    //病例待审核列表
    @GetMapping(value = "/list")
    public Result<IPage<AdminMedicalHistory>> queryPageList(AdminMedicalHistory adminMedicalHistory,
                                                            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                            @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                            HttpServletRequest req, String sstitle, String ssname) {
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, req.getParameterMap());
        //未初审的
//        queryWrapper.eq("first_trial","0").or().eq( "first_trial","1" );
        queryWrapper.in("first_trial", "0", "1");
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")) {
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }

        Page<AdminMedicalHistory> page = new Page<AdminMedicalHistory>(pageNo, pageSize);
        IPage<AdminMedicalHistory> pageList = adminMedicalHistoryService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    //    初审通过病例列表
    @GetMapping(value = "/list2")
    public Result<IPage<AdminMedicalHistory>> list2(AdminMedicalHistory adminMedicalHistory,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req, String sstitle, String ssname) {
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, req.getParameterMap());
        //不能是初审通过未二次上传的  应该是初审通过未分配的
        queryWrapper.eq("first_trial", "2");
        queryWrapper.eq("allocation", "1");
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")) {
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }
        queryWrapper.orderByDesc("auditor_time");
        Page<AdminMedicalHistory> page = new Page<AdminMedicalHistory>(pageNo, pageSize);
        IPage<AdminMedicalHistory> pageList = adminMedicalHistoryService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    //    专家审核病例列表
    @GetMapping(value = "/list3")
    public Result<IPage<AdminMedicalHistory>> list3(AdminMedicalHistory adminMedicalHistory,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req, String sstitle, String ssname) {
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, req.getParameterMap());
        //已分配的就算专家审核病理列表  不论是专家 未审理 没通过  通过了都算专家审核病例列表
        queryWrapper.eq("allocation", "2");
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")) {
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }
        queryWrapper.orderByDesc("zjsp_time");
        Page<AdminMedicalHistory> page = new Page<AdminMedicalHistory>(pageNo, pageSize);
        IPage<AdminMedicalHistory> pageList = adminMedicalHistoryService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    //优秀病例列表（专家审核通过的病例列表）
    @GetMapping(value = "/list4")
    public Result<IPage<AdminMedicalHistory>> list4(AdminMedicalHistory adminMedicalHistory,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req, String sstitle, String ssname) {
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, req.getParameterMap());
        //专家审核通过
        queryWrapper.eq("type", "2");
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")) {
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }
        Page<AdminMedicalHistory> page = new Page<AdminMedicalHistory>(pageNo, pageSize);
        IPage<AdminMedicalHistory> pageList = adminMedicalHistoryService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    //可以分配的数量
    @PostMapping(value = "/listNum")
    public Result<Integer> listNum() {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        String orgCode = sysUser.getOrgCode();

        QueryWrapper<AdminMedicalHistory> queryWrapper = new QueryWrapper<>();
        //后台初审通过  但没分配
        queryWrapper.eq("first_trial", "2");
        queryWrapper.eq("allocation", "1");
        queryWrapper.eq("sys_org_code", orgCode);
        List<AdminMedicalHistory> list = adminMedicalHistoryService.list(queryWrapper);
        return Result.OK(list.size());
    }

    //分配 给病例添加分配人  给专家账号分配数清零
    @PostMapping(value = "/ksfp")
    public Result<String> ksfp() {

        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();


        //查询所有专家（分配数量不为0的）
        LambdaQueryWrapper<AdminCompSelect> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(AdminCompSelect::getDoctorAndSpecialist, "2");
        queryWrapper.ne(AdminCompSelect::getAllocationNum, 0);
        queryWrapper.eq(AdminCompSelect::getSysOrgCode, sysUser.getOrgCode());

        List<AdminCompSelect> list1 = adminCompSelectService.list(queryWrapper);
        for (int o = 0; o < list1.size(); o++) {
            System.err.println(list1.get(o).toString());
        }

        //查询所有没有分配专家的病例
        LambdaQueryWrapper<AdminMedicalHistory> queryWrapper2 = new LambdaQueryWrapper<>();
        //后台初审通过  但没分配
        queryWrapper2.eq(AdminMedicalHistory::getFirstTrial, "2");
        queryWrapper2.eq(AdminMedicalHistory::getAllocation, "1");
        queryWrapper2.eq(AdminMedicalHistory::getSysOrgCode, sysUser.getOrgCode());

        List<AdminMedicalHistory> list = adminMedicalHistoryService.list(queryWrapper2);

        //总人数
        Integer userCount = list1.size();
        //总数
        Integer clientCount = list.size();
        //余数
//        Integer remainderCount = clientCount % userCount;

        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < userCount; i++) {
            System.err.println(1);
//            Integer divideCount = clientCount / userCount;
            Integer divideCount = list1.get(i).getAllocationNum();
            for (int j = 0; j < divideCount; j++) {
                System.err.println(2);
                sb.setLength(0);
                if (userCount * (j) + i <= clientCount - 1) {
                    //list1.get(i) 给专家账号分配数清零
                    AdminCompSelect adminUser = new AdminCompSelect();
                    adminUser.setId(list1.get(i).getId());
                    adminUser.setAllocationNum(divideCount - (j + 1));
                    adminCompSelectService.updateById(adminUser);
                    //list.get(userCount * (j) + i)给病例添加分配人
                    AdminMedicalHistory adminMedicalHistory = new AdminMedicalHistory();
                    adminMedicalHistory.setId(list.get(userCount * (j) + i).getId());
                    adminMedicalHistory.setAllocation("2");
                    adminMedicalHistory.setAllocationZjname(list1.get(i).getName());
                    adminMedicalHistory.setAllocationZjphone(list1.get(i).getPhone());
                    adminMedicalHistoryService.updateById(adminMedicalHistory);
//                    sb.append(list1.get(i)).append(list.get(userCount * (j) + i));
//                    System.out.println(sb.toString());
                }
            }
        }
        return Result.OK("分配成功");
    }

    /**
     * 添加
     *
     * @param adminMedicalHistory
     * @return
     */
    @AutoLog(value = "病历管理-添加")
    @ApiOperation(value = "病历管理-添加", notes = "病历管理-添加")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody AdminMedicalHistory adminMedicalHistory) {
        adminMedicalHistory.setIsSecondaryUpload("1");
        adminMedicalHistory.setFirstTrial("0");
        adminMedicalHistory.setSecondaryUpload("1");
        adminMedicalHistory.setType("0");
        adminMedicalHistory.setAllocation("1");
        adminMedicalHistoryService.save(adminMedicalHistory);
        return Result.OK("添加成功！");
    }

    @PostMapping(value = "/ORC")
    public Result<String> ORC(@RequestBody ORCPicUrl orcPicUrl) throws Exception {
        com.aliyun.ocr_api20210707.Client client = createClient("LTAI5tD17r71nA9bfKtzcayJ", "EblO65wHRfmOtl3GrAeBbAu8i05H8O");
        com.aliyun.ocr_api20210707.models.RecognizeAdvancedRequest recognizeAdvancedRequest = new com.aliyun.ocr_api20210707.models.RecognizeAdvancedRequest()
                .setUrl(orcPicUrl.getPicUrl());
        com.aliyun.teautil.models.RuntimeOptions runtime = new com.aliyun.teautil.models.RuntimeOptions();
        try {
            // 复制代码运行请自行打印 API 的返回值
            RecognizeAdvancedResponse recognizeAdvancedResponse = client.recognizeAdvancedWithOptions(recognizeAdvancedRequest, runtime);
            String data = recognizeAdvancedResponse.getBody().data;
//            System.err.println(data);
            JSONObject jsonObject = JSONObject.fromObject(data);

            String content = jsonObject.getString("content");
            return Result.OK(content);
        } catch (TeaException error) {
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
            return Result.error("识别错误1:" + error.message);
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
            return Result.error("识别错误2:" + error.message);
        }
    }

    public static com.aliyun.ocr_api20210707.Client createClient(String accessKeyId, String accessKeySecret) throws Exception {
        com.aliyun.teaopenapi.models.Config config = new com.aliyun.teaopenapi.models.Config()
                // 必填，您的 AccessKey ID
                .setAccessKeyId(accessKeyId)
                // 必填，您的 AccessKey Secret
                .setAccessKeySecret(accessKeySecret);
        // 访问的域名
        config.endpoint = "ocr-api.cn-hangzhou.aliyuncs.com";
        return new com.aliyun.ocr_api20210707.Client(config);
    }

    /**
     * 编辑
     *
     * @param adminMedicalHistory
     * @return
     */
    @AutoLog(value = "病历管理-编辑")
    @ApiOperation(value = "病历管理-编辑", notes = "病历管理-编辑")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody AdminMedicalHistory adminMedicalHistory) {
//        if (adminMedicalHistory.getType()!=null){
//            adminMedicalHistory.setZjspTime( new Date(  ) );
//        }
        if (adminMedicalHistory.getFirstTrial() != null) {
            adminMedicalHistory.setAuditorTime(new Date());
        }
        adminMedicalHistoryService.updateById(adminMedicalHistory);
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "病历管理-通过id删除")
    @ApiOperation(value = "病历管理-通过id删除", notes = "病历管理-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        adminMedicalHistoryService.removeById(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "病历管理-批量删除")
    @ApiOperation(value = "病历管理-批量删除", notes = "病历管理-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.adminMedicalHistoryService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功!");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "病历管理-通过id查询")
    @ApiOperation(value = "病历管理-通过id查询", notes = "病历管理-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<AdminMedicalHistory> queryById(@RequestParam(name = "id", required = true) String id) {
        AdminMedicalHistory adminMedicalHistory = adminMedicalHistoryService.getById(id);
        if (adminMedicalHistory == null) {
            return Result.error("未找到对应数据", null);
        }
        return Result.OK(adminMedicalHistory);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param adminMedicalHistory
     */
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, AdminMedicalHistory adminMedicalHistory,String sstitle,String ssname) {
//        adminMedicalHistory.setTitle( sstitle );
//        adminMedicalHistory.setName( ssname );
//        adminMedicalHistory.setFirstTrial( "0" );
//        return super.exportXls(request, adminMedicalHistory, AdminMedicalHistory.class, "待审核病历列表");
//    }
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AdminMedicalHistory adminMedicalHistory, String sstitle, String ssname) {
        String title = "待审核病历列表";
        // Step.1 组装查询条件
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        queryWrapper.in("first_trial", "0", "1");
        // Step.2 获取导出数据
        List<AdminMedicalHistory> pageList = service.list(queryWrapper);


        List<AdminMedicalHistory> exportList = null;

        // 过滤选中数据
        String selections = request.getParameter("selections");
        if (oConvertUtils.isNotEmpty(selections)) {
            List<String> selectionList = Arrays.asList(selections.split(","));
            exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
        } else {
            exportList = pageList;
        }
        //导出不太可能 一是慢这个没啥问题 二是只能通过
        int a = exportList.size();
        for (int i = 0; i < a; i++) {
            if (exportList.get(i).getSubmitterName() == null) {
                QueryWrapper<AdminUser> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("phone", exportList.get(i).getPhone());
                AdminUser storeMember1 = adminUserService.getOne(queryWrapper2);
                exportList.get(i).setSubmitterName(storeMember1.getName());
            }
        }

        // Step.3 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
        mv.addObject(NormalExcelConstants.CLASS, AdminMedicalHistory.class);
        //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
        ExportParams exportParams = new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
        exportParams.setImageBasePath(upLoadPath);
        //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
        mv.addObject(NormalExcelConstants.PARAMS, exportParams);
        mv.addObject(NormalExcelConstants.DATA_LIST, exportList);
        return mv;
    }

    private String getId(AdminMedicalHistory item) {
        try {
            return PropertyUtils.getProperty(item, "id").toString();
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    @RequestMapping(value = "/exportXls2")
    public ModelAndView exportXls2(HttpServletRequest request, AdminMedicalHistory adminMedicalHistory, String sstitle, String ssname) {
//        adminMedicalHistory.setTitle( sstitle );
//        adminMedicalHistory.setName( ssname );
//        adminMedicalHistory.setFirstTrial( "2" );
//        adminMedicalHistory.setAllocation( "1" );
//        return super.exportXls(request, adminMedicalHistory, AdminMedicalHistory.class, "初审通过病例列表");
        String title = "初审通过病例列表";
        // Step.1 组装查询条件
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        queryWrapper.eq("allocation", "1");
        queryWrapper.eq("first_trial", "2");
        // Step.2 获取导出数据
        List<AdminMedicalHistory> pageList = service.list(queryWrapper);


        List<AdminMedicalHistory> exportList = null;

        // 过滤选中数据
        String selections = request.getParameter("selections");
        if (oConvertUtils.isNotEmpty(selections)) {
            List<String> selectionList = Arrays.asList(selections.split(","));
            exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
        } else {
            exportList = pageList;
        }
        int a = exportList.size();
        for (int i = 0; i < a; i++) {
            if (exportList.get(i).getSubmitterName() == null) {
                QueryWrapper<AdminUser> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("phone", exportList.get(i).getPhone());
                AdminUser storeMember1 = adminUserService.getOne(queryWrapper2);
                exportList.get(i).setSubmitterName(storeMember1.getName());
            }
        }
        // Step.3 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
        mv.addObject(NormalExcelConstants.CLASS, AdminMedicalHistory.class);
        //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
        ExportParams exportParams = new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
        exportParams.setImageBasePath(upLoadPath);
        //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
        mv.addObject(NormalExcelConstants.PARAMS, exportParams);
        mv.addObject(NormalExcelConstants.DATA_LIST, exportList);
        return mv;
    }

    @RequestMapping(value = "/exportXls3")
    public ModelAndView exportXls3(HttpServletRequest request, AdminMedicalHistory adminMedicalHistory, String sstitle, String ssname) {
//        adminMedicalHistory.setTitle( sstitle );
////        adminMedicalHistory.setName( ssname );
////        adminMedicalHistory.setAllocation( "2" );
////        return super.exportXls(request, adminMedicalHistory, AdminMedicalHistory.class, "专家审核病例列表");
        String title = "专家审核病例列表";
        // Step.1 组装查询条件
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        queryWrapper.eq("allocation", "2");
        // Step.2 获取导出数据
        List<AdminMedicalHistory> pageList = service.list(queryWrapper);


        List<AdminMedicalHistory> exportList = null;

        // 过滤选中数据
        String selections = request.getParameter("selections");
        if (oConvertUtils.isNotEmpty(selections)) {
            List<String> selectionList = Arrays.asList(selections.split(","));
            exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
        } else {
            exportList = pageList;
        }
        int a = exportList.size();
        for (int i = 0; i < a; i++) {
            if (exportList.get(i).getSubmitterName() == null) {
                QueryWrapper<AdminUser> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("phone", exportList.get(i).getPhone());
                AdminUser storeMember1 = adminUserService.getOne(queryWrapper2);
                exportList.get(i).setSubmitterName(storeMember1.getName());
            }
        }
        // Step.3 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
        mv.addObject(NormalExcelConstants.CLASS, AdminMedicalHistory.class);
        //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
        ExportParams exportParams = new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
        exportParams.setImageBasePath(upLoadPath);
        //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
        mv.addObject(NormalExcelConstants.PARAMS, exportParams);
        mv.addObject(NormalExcelConstants.DATA_LIST, exportList);
        return mv;
    }

    @RequestMapping(value = "/exportXls4")
    public ModelAndView exportXls4(HttpServletRequest request, AdminMedicalHistory adminMedicalHistory, String sstitle, String ssname) {
//        adminMedicalHistory.setTitle( sstitle );
//        adminMedicalHistory.setName( ssname );
//        adminMedicalHistory.setType( "2" );
//        return super.exportXls(request, adminMedicalHistory, AdminMedicalHistory.class, "优秀病例列表");
        String title = "优秀病例列表";
        // Step.1 组装查询条件
        QueryWrapper<AdminMedicalHistory> queryWrapper = QueryGenerator.initQueryWrapper(adminMedicalHistory, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (sstitle != null) {
            queryWrapper.like("title", sstitle);
        }
        if (ssname != null) {
            queryWrapper.like("submitter_name", ssname);
        }
        queryWrapper.eq("type", "2");
        // Step.2 获取导出数据
        List<AdminMedicalHistory> pageList = service.list(queryWrapper);


        List<AdminMedicalHistory> exportList = null;

        // 过滤选中数据
        String selections = request.getParameter("selections");
        if (oConvertUtils.isNotEmpty(selections)) {
            List<String> selectionList = Arrays.asList(selections.split(","));
            exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
        } else {
            exportList = pageList;
        }
        int a = exportList.size();
        for (int i = 0; i < a; i++) {
            if (exportList.get(i).getSubmitterName() == null) {
                QueryWrapper<AdminUser> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("phone", exportList.get(i).getPhone());
                AdminUser storeMember1 = adminUserService.getOne(queryWrapper2);
                exportList.get(i).setSubmitterName(storeMember1.getName());
            }
        }
        // Step.3 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
        mv.addObject(NormalExcelConstants.CLASS, AdminMedicalHistory.class);
        //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
        ExportParams exportParams = new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
        exportParams.setImageBasePath(upLoadPath);
        //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
        mv.addObject(NormalExcelConstants.PARAMS, exportParams);
        mv.addObject(NormalExcelConstants.DATA_LIST, exportList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AdminMedicalHistory.class);
    }

    /**
     * 退回
     *
     * @param id
     * @return
     */
    @AutoLog(value = "病历管理-退回")
    @ApiOperation(value = "病历管理-退回", notes = "病历管理-退回")
    @RequestMapping(value = "/returnDetail", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> returnDetail(@RequestBody String id) {
        String[] split = id.split("=");
        String s = split[0];
        AdminMedicalHistory adminMedicalHistory = adminMedicalHistoryService.getById(s);
        if (null == adminMedicalHistory) {
            return Result.error("数据不存在");
        }
        adminMedicalHistory.setFirstTrial("0");

        adminMedicalHistoryService.updateById(adminMedicalHistory);
        return Result.OK("操作成功!");
    }

}
