package org.jeecg.modules.adminuser.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.SecurityUtils;
import org.checkerframework.checker.units.qual.A;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.util.JwtUtil;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.modules.admincasehistory.service.IAdminCaseNameService;
import org.jeecg.modules.admincasehistory.service.IAdminMedicalHistoryService;
import org.jeecg.modules.admincasehistory.service.IAdminPlatformService;
import org.jeecg.modules.admincasehistory.service.IAdminUploadingNameService;
import org.jeecg.modules.adminuser.entity.AdminTransferAccounts;
import org.jeecg.modules.adminuser.entity.AdminUser;
import org.jeecg.modules.adminuser.mapper.AdminTransferAccountsMapper;
import org.jeecg.modules.adminuser.service.IAdminPrivacyService;
import org.jeecg.modules.adminuser.service.IAdminTransferAccountsService;
import org.jeecg.modules.adminuser.service.IAdminUserService;
import org.jeecg.modules.adminwjdc.entity.AdminTopic;
import org.jeecg.modules.adminwjdc.service.IAdminTopicService;
import org.jeecg.modules.base.service.BaseCommonService;
import org.jeecg.modules.pay.example.config.Config;
import org.jeecg.modules.pay.sdk.base.YzhConfig;
import org.jeecg.modules.pay.sdk.notify.NotifyClient;
import org.jeecg.modules.pay.sdk.notify.domain.NotifyRequest;
import org.jeecg.modules.pay.sdk.notify.domain.NotifyResponse;
import org.jeecg.modules.pay.sdk.payment.domain.NotifyOrderData;
import org.jeecg.modules.pay.sdk.payment.domain.NotifyOrderRequest;
import org.jeecg.modules.quesmanage.service.IQuesManageDetailService;
import org.jeecg.modules.quesmanage.service.IQuesManageService;
import org.jeecg.modules.quesmanage.service.IQuesSubNoteService;
import org.jeecg.modules.system.service.ISysUserService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Description: 转账记录表
 * @Author: jeecg-boot
 * @Date:   2023-08-07
 * @Version: V1.0
 */
@Service
public class AdminTransferAccountsServiceImpl extends ServiceImpl<AdminTransferAccountsMapper, AdminTransferAccounts> implements IAdminTransferAccountsService {

    @Autowired
    private RedisUtil redisUtil;
    @Resource
    private BaseCommonService baseCommonService;
    @Autowired
    private IAdminUserService adminUserService;
    @Autowired
    private IAdminTopicService adminTopicService;
    @Autowired
    private IAdminTransferAccountsService adminTransferAccountsService;
    @Autowired
    private ISysUserService sysUserService;


    private static YzhConfig config = Config.getYzhConfig();

    private static NotifyClient client = new NotifyClient(config);

    @Override
    public String notifyUrl(String requestId, String data, String mess, String timestamp, String sign, String sign_type) {
        NotifyRequest request = new NotifyRequest();
        request.setData(data);
        request.setMess(mess);
        request.setSign(sign);
        request.setTimestamp(timestamp);

        try {
            // 订单支付状态回调通知
            NotifyResponse<NotifyOrderRequest> response = client.notifyDecoder(request, NotifyOrderRequest.class);
            NotifyOrderRequest notifyRequest = response.getData();
            NotifyOrderData notifyOrderData = notifyRequest.getData();
            AdminTransferAccounts adminTransferAccounts = new AdminTransferAccounts();
            adminTransferAccounts.setOrderId(notifyOrderData.getOrderId());
            adminTransferAccounts.setPay(notifyOrderData.getPay());
            adminTransferAccounts.setBrokerId(notifyOrderData.getBrokerId());
            adminTransferAccounts.setDealerId(notifyOrderData.getDealerId());
            adminTransferAccounts.setRealName(notifyOrderData.getRealName());
            adminTransferAccounts.setCardNo(notifyOrderData.getCardNo());
            adminTransferAccounts.setIdCard(notifyOrderData.getIdCard());
            adminTransferAccounts.setPhoneNo(notifyOrderData.getPhoneNo());
            adminTransferAccounts.setStatus(notifyOrderData.getStatus());
            adminTransferAccounts.setStatusDetail(notifyOrderData.getStatusDetail());
            adminTransferAccounts.setStatusMessage(notifyOrderData.getStatusMessage());
            adminTransferAccounts.setStatusDetailMessage(notifyOrderData.getStatusDetailMessage());
            adminTransferAccounts.setBrokerAmount(notifyOrderData.getBrokerAmount());
            adminTransferAccounts.setRef(notifyOrderData.getRef());
            adminTransferAccounts.setBrokerBankBill(notifyOrderData.getBrokerBankBill());
            adminTransferAccounts.setWithdrawPlatform(notifyOrderData.getWithdrawPlatform());
            adminTransferAccounts.setCreatedAt(notifyOrderData.getCreatedAt());
            adminTransferAccounts.setFinishedTime(notifyOrderData.getFinishedTime());
            adminTransferAccounts.setBrokerFee(notifyOrderData.getBrokerFee());
            adminTransferAccounts.setBrokerDeductFee(notifyOrderData.getBrokerDeductFee());
            adminTransferAccounts.setPayRemark(notifyOrderData.getPayRemark());
            adminTransferAccounts.setUserFee(notifyOrderData.getUserFee());
            adminTransferAccounts.setBankName(notifyOrderData.getBankName());
            adminTransferAccounts.setProjectId(notifyOrderData.getProjectId());
            adminTransferAccounts.setUserId(notifyOrderData.getUserId());
            adminTransferAccounts.setNotifyId(notifyRequest.getNotifyId());
            adminTransferAccounts.setNotifyTime(notifyRequest.getNotifyTime());
            adminTransferAccountsService.save(adminTransferAccounts);
            return "success";
        } catch (Exception e) {
            return "error";
        }

    }


    public String yzhAddBatch(String requestId, String data, String mess, String timestamp, String sign, String sign_type) {
        NotifyRequest request = new NotifyRequest();
        request.setData(data);
        request.setMess(mess);
        request.setSign(sign);
        request.setTimestamp(timestamp);

        try {
            // 订单支付状态回调通知
            NotifyResponse<NotifyOrderRequest> response = client.notifyDecoder(request, NotifyOrderRequest.class);
            NotifyOrderRequest notifyRequest = response.getData();
            NotifyOrderData notifyOrderData = notifyRequest.getData();
            AdminTransferAccounts adminTransferAccounts = new AdminTransferAccounts();
            adminTransferAccounts.setOrderId(notifyOrderData.getOrderId());
            adminTransferAccounts.setPay(notifyOrderData.getPay());
            adminTransferAccounts.setBrokerId(notifyOrderData.getBrokerId());
            adminTransferAccounts.setDealerId(notifyOrderData.getDealerId());
            adminTransferAccounts.setRealName(notifyOrderData.getRealName());
            adminTransferAccounts.setCardNo(notifyOrderData.getCardNo());
            adminTransferAccounts.setIdCard(notifyOrderData.getIdCard());
            adminTransferAccounts.setPhoneNo(notifyOrderData.getPhoneNo());
            adminTransferAccounts.setStatus(notifyOrderData.getStatus());
            adminTransferAccounts.setStatusDetail(notifyOrderData.getStatusDetail());
            adminTransferAccounts.setStatusMessage(notifyOrderData.getStatusMessage());
            adminTransferAccounts.setStatusDetailMessage(notifyOrderData.getStatusDetailMessage());
            adminTransferAccounts.setBrokerAmount(notifyOrderData.getBrokerAmount());
            adminTransferAccounts.setRef(notifyOrderData.getRef());
            adminTransferAccounts.setBrokerBankBill(notifyOrderData.getBrokerBankBill());
            adminTransferAccounts.setWithdrawPlatform(notifyOrderData.getWithdrawPlatform());
            adminTransferAccounts.setCreatedAt(notifyOrderData.getCreatedAt());
            adminTransferAccounts.setFinishedTime(notifyOrderData.getFinishedTime());
            adminTransferAccounts.setBrokerFee(notifyOrderData.getBrokerFee());
            adminTransferAccounts.setBrokerDeductFee(notifyOrderData.getBrokerDeductFee());
            adminTransferAccounts.setPayRemark(notifyOrderData.getPayRemark());
            adminTransferAccounts.setUserFee(notifyOrderData.getUserFee());
            adminTransferAccounts.setBankName(notifyOrderData.getBankName());
            adminTransferAccounts.setProjectId(notifyOrderData.getProjectId());
            adminTransferAccounts.setUserId(notifyOrderData.getUserId());
            adminTransferAccounts.setNotifyId(notifyRequest.getNotifyId());
            adminTransferAccounts.setNotifyTime(notifyRequest.getNotifyTime());
            adminTransferAccountsService.save(adminTransferAccounts);
            return "success";
        } catch (Exception e) {
            return "error";
        }
    }

    @Override
    public Result<?>transList(String authorization, Integer pageNo, Integer pageSize, HttpServletRequest req) {
        Result<?> result = new Result<>();
        if (authorization.equals("")) {
            result.setMessage("token不能为空");
            return result;
        }

        String userPhone = JwtUtil.getUsername(authorization);

        //校验token==================
        if (!redisUtil.hasKey(CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone)) {
            result.setMessage("TOKEN失效");
            result.setCode(201);
            return result;
        }
        try {

            //1. 校验用户是否有效
            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone", userPhone);

            AdminUser storeMember1 = adminUserService.getOne(queryWrapper);

            if (storeMember1 == null) {
                result.setMessage("token校验该用户不存在");
                baseCommonService.addLog("用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null);
                return result;
            }

            QueryWrapper<AdminTransferAccounts> queryWrapper1 = QueryGenerator.initQueryWrapper(new AdminTransferAccounts(), req.getParameterMap());
            queryWrapper1.eq("phone_no", storeMember1.getPhone());
            queryWrapper1.orderByDesc("create_time");
            Page<AdminTransferAccounts> page = new Page<AdminTransferAccounts>(pageNo, pageSize);
            IPage<AdminTransferAccounts> pageList = adminTransferAccountsService.page(page, queryWrapper1);
            return Result.OK(pageList) ;
        } catch (Exception e) {

            return Result.OK("请求失败") ;
        }
    }


}
