package org.jeecg.modules.adminuser.service.impl;

import com.alipay.api.internal.util.codec.Base64;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import net.sf.json.JSONObject;
import org.apache.http.client.methods.HttpGet;
import org.apache.shiro.SecurityUtils;
import org.checkerframework.checker.units.qual.A;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.util.JwtUtil;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.PasswordUtil;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.adminuser.entity.AdminCompSelect;
import org.jeecg.modules.adminuser.entity.AdminTransferAccounts;
import org.jeecg.modules.adminuser.entity.AdminUser;
import org.jeecg.modules.adminuser.entity.AdminUserVO;
import org.jeecg.modules.adminuser.mapper.AdminTransferAccountsMapper;
import org.jeecg.modules.adminuser.mapper.AdminUserMapper;
import org.jeecg.modules.adminuser.service.IAdminCompSelectService;
import org.jeecg.modules.adminuser.service.IAdminUserService;
import org.jeecg.modules.base.service.BaseCommonService;
import org.jeecg.modules.pay.example.config.Config;
import org.jeecg.modules.pay.example.utils.BaseUtil;
import org.jeecg.modules.pay.sdk.apiusersign.ApiUserSignServiceClient;
import org.jeecg.modules.pay.sdk.apiusersign.domain.*;
import org.jeecg.modules.pay.sdk.authentication.AuthenticationClient;
import org.jeecg.modules.pay.sdk.authentication.domain.BankCardFourAuthConfirmRequest;
import org.jeecg.modules.pay.sdk.authentication.domain.BankCardFourAuthConfirmResponse;
import org.jeecg.modules.pay.sdk.authentication.domain.BankCardFourAuthVerifyRequest;
import org.jeecg.modules.pay.sdk.authentication.domain.BankCardFourAuthVerifyResponse;
import org.jeecg.modules.pay.sdk.base.YzhConfig;
import org.jeecg.modules.pay.sdk.base.YzhRequest;
import org.jeecg.modules.pay.sdk.base.YzhResponse;
import org.jeecg.modules.pay.sdk.payment.PaymentClient;
import org.jeecg.modules.pay.sdk.payment.domain.*;
import org.jeecg.modules.system.util.SecurityUtil;
import org.jeecg.modules.utils.HttpClientUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import sun.net.www.http.HttpClient;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.nio.charset.Charset;
import java.text.SimpleDateFormat;
import java.util.*;

import static org.jeecg.modules.pay.sdk.utils.DESUtil.tripleDesEncrypt;

/**
 * @Description: 用户管理
 * @Author: jeecg-boot
 * @Date: 2022-12-16
 * @Version: V1.0
 */
@Service
public class AdminUserServiceImpl extends ServiceImpl<AdminUserMapper, AdminUser> implements IAdminUserService {

    @Value("${yzh.dealer_id}")
    private String dealer_id;

    @Value("${yzh.broker_id}")
    private String broker_id;

    @Value("${ip.ip}")
    private String host;

    private static YzhConfig config = Config.getYzhConfig();
    private static ApiUserSignServiceClient client = new ApiUserSignServiceClient(config);
    private static AuthenticationClient clientBank = new AuthenticationClient(config);
    private static PaymentClient clientPay = new PaymentClient(config);


    @Resource
    private AdminUserMapper adminUserMapper;
    @Autowired
    private BaseCommonService baseCommonService;
    @Autowired
    private RedisUtil redisUtil;
    @Autowired
    private AdminTransferAccountsMapper adminTransferAccountsMapper;
    @Autowired
    private IAdminUserService adminUserService;
    @Autowired
    private IAdminCompSelectService adminCompSelectService;


    @Override
    public Integer num(QueryWrapper<AdminUser> queryWrapper) {
        return adminUserMapper.num(queryWrapper);
    }

    @Override
    public Result saveUser(AdminUser adminUser) {

        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        adminUser.setCompName(user.getRealname());
        String phone = adminUser.getPhone();
        String compName = adminUser.getCompName();
        adminUser.setDoctorAndSpecialist("1");
        String salt = oConvertUtils.randomGen(8);
        adminUser.setSalt(salt);
        if (adminUser.getPassword() == null) {
            adminUser.setPassword("123456");
        }
        if (adminUser.getPassword().equals("")) {
            adminUser.setPassword("123456");
        }
        adminUser.setWisMhu("允许");
        adminUser.setCompleteInformation(1);
        adminUser.setIsTrue("1");
        adminUser.setSysOrgCode(user.getOrgCode());
        adminUser.setYzh(user.getYzh());
        adminUser.setWisWjdc("允许");
        String passwordEncode = PasswordUtil.encrypt(adminUser.getPhone(), adminUser.getPassword(), salt);
        adminUser.setPassword(passwordEncode);


        QueryWrapper<AdminUser> adminUserQueryWrapper = new QueryWrapper<>();
        adminUserQueryWrapper.eq("phone", phone);
//        adminUserQueryWrapper.eq("doctor_and_specialist", "1");
        AdminUser adminUsers = adminUserService.getOne(adminUserQueryWrapper);

        if (null != adminUsers) {
            AdminCompSelect adminCompSelect = new AdminCompSelect();
            adminCompSelect.setOrderId(adminUsers.getId());
            adminCompSelect.setPhone(phone);
            adminCompSelect.setCompName(compName);
            adminCompSelect.setSysOrgCode(adminUser.getSysOrgCode());
            adminCompSelect.setKsName(adminUser.getKsname());
            adminCompSelect.setDwName(adminUser.getDwname());
            adminCompSelect.setAvatar(adminUser.getAvatar());
            adminCompSelect.setCardPic(adminUser.getCardPic());
            adminCompSelect.setDoctorAndSpecialist("1");
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setWisMhu("允许");
            adminCompSelect.setWisWjdc("允许");
            adminCompSelect.setName(adminUser.getName());
            adminCompSelect.setYzh(user.getYzh());


            QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
            adminCompSelectQueryWrapper.eq("phone", phone);
            adminCompSelectQueryWrapper.eq("comp_name", compName);
            adminCompSelectQueryWrapper.eq("sys_org_code", adminUser.getSysOrgCode());
//            adminCompSelectQueryWrapper.eq("doctor_and_specialist", "1");
            List<AdminCompSelect> list = adminCompSelectService.list(adminCompSelectQueryWrapper);

            if (null != list && list.size() > 0) {
                return Result.error("该手机号已存在该公司,请更换手机号进行注册");
            } else {
                adminCompSelectService.save(adminCompSelect);
            }
        } else {
            adminUser.setId(UUID.randomUUID().toString().replace("-", ""));

            AdminCompSelect adminCompSelect = new AdminCompSelect();
            adminCompSelect.setOrderId(adminUser.getId());
            adminCompSelect.setPhone(phone);
            adminCompSelect.setCompName(compName);
            adminCompSelect.setSysOrgCode(adminUser.getSysOrgCode());
            adminCompSelect.setKsName(adminUser.getKsname());
            adminCompSelect.setDwName(adminUser.getDwname());
            adminCompSelect.setAvatar(adminUser.getAvatar());
            adminCompSelect.setCardPic(adminUser.getCardPic());
            adminCompSelect.setDoctorAndSpecialist("1");
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setWisMhu("允许");
            adminCompSelect.setWisWjdc("允许");
            adminCompSelect.setName(adminUser.getName());
            adminCompSelect.setYzh(user.getYzh());

            QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
            adminCompSelectQueryWrapper.eq("phone", phone);
            adminCompSelectQueryWrapper.eq("comp_name", compName);
            adminCompSelectQueryWrapper.eq("sys_org_code", adminUser.getSysOrgCode());
//            adminCompSelectQueryWrapper.eq("doctor_and_specialist", "1");
            List<AdminCompSelect> list = adminCompSelectService.list(adminCompSelectQueryWrapper);

            if (null != list && list.size() > 0) {
                return Result.error("该手机号已存在该公司,请更换手机号进行注册");
            } else {
                adminCompSelectService.save(adminCompSelect);
            }
            adminUser.setName("");
            adminUser.setDwname("");
            adminUser.setKsname("");
            adminUser.setCardPic("");
            this.save(adminUser);

        }
        return Result.OK("操作成功");

    }

    @Override
    public Result<?> giveMoney(AdminUser adminUser1) {
        String id = adminUser1.getId();


        AdminCompSelect adminCompSelect = adminCompSelectService.getById(id);
        String yzh = adminCompSelect.getYzh();
        if ("0".equals(yzh)) {
            return Result.error("请确认云账户权限是否开启");
        }

        CreateBatchOrderRequest request = new CreateBatchOrderRequest();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Date date = new Date();
        String format = sdf.format(date);
        Random random = new Random();
        int randomNumber = random.nextInt(900000) + 100000;

        request.setBatchId("batchaId" + format + randomNumber);
        request.setDealerId(dealer_id);
        request.setBrokerId(broker_id);
        request.setChannel("银行卡");
        request.setWxAppId("");
        request.setTotalPay(String.valueOf(adminUser1.getMoney()));
        request.setTotalCount("1");
        request.setOrderList(getBatchOrderInfoList(adminUser1));

        YzhResponse<CreateBatchOrderResponse> response = null;
        try {
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = clientPay.createBatchOrder(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                CreateBatchOrderResponse data = response.getData();
                System.out.println("请求成功返回批次号：" + data.getBatchId());
                for (BatchOrderResult res : data.getResultList()) {
                    System.out.println("订单详情");
                    System.out.println(res);
                    System.out.println("-------------------");
                    baseCommonService.addLog("请求成功转账的唯一标识request-id： " + requestId + "", CommonConstant.LOG_TYPE_2, 2);
                    return Result.ok("操作成功");

                }
            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + "-" + response.getMessage());
                baseCommonService.addLog("发生异常转账的唯一标识request-id： " + requestId + response.getCode() + "-" + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
                return Result.error("发生异常：" + response.getCode() + "-" + response.getMessage());
            }
            return Result.ok("操作成功");
        } catch (Exception e) {
            return Result.error("请求失败");
        }
    }


    // 获取协议预览 URL
    @Override
    public Result getUserAgreement() {
        ApiUserSignContractRequest request = new ApiUserSignContractRequest();
        request.setDealerId(dealer_id);
        request.setBrokerId(broker_id);
        YzhResponse<ApiUserSignContractResponse> response = null;
        try {
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = client.apiUserSignContract(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                ApiUserSignContractResponse data = response.getData();
                baseCommonService.addLog("获取协议预览 URL请求的唯一标识request-id： " + requestId, CommonConstant.LOG_TYPE_2, 2);
                return Result.ok(data);
            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + response.getMessage());
                baseCommonService.addLog("获取协议预览 URL请求的唯一标识request-id： " + requestId + "返回结果：" + response.getCode() + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
                return Result.error("发生异常：" + response.getCode() + response.getMessage());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return Result.ok();
    }


    @Override
    public Result<?> agreeUserAgreement(String name, String card) {
        ApiUserSignRequest request = new ApiUserSignRequest();
        request.setDealerId(dealer_id);
        request.setBrokerId(broker_id);
        request.setRealName(name);
        request.setIdCard(card);
        request.setCardType("idcard");
        YzhResponse<ApiUserSignResponse> response = null;
        try {
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = client.apiUserSign(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                ApiUserSignResponse data = response.getData();
                baseCommonService.addLog("签约协议请求的唯一标识request-id： " + requestId, CommonConstant.LOG_TYPE_2, 2);
                System.out.println("请求成功：" + data);
                return Result.ok(data);

            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + response.getMessage());
                baseCommonService.addLog("签约协议请求的唯一标识request-id： " + requestId + "返回结果：" + response.getCode() + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return Result.ok();
    }

    @Override
    public Result<?> perfectInformation(AdminUserVO adminUserVO, String authorization) {

//        if (authorization.equals("")) {
//            return Result.error("token不能为空");
//        }
//        String userPhone = JwtUtil.getUsername(authorization);
//        //校验token==================
//        if (!redisUtil.hasKey(CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone)) {
//            return Result.error("TOKEN失效");
//        }
        try {
            //1. 校验用户是否有效
//            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
//            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
//            queryWrapper.eq("phone", userPhone);
//            AdminUser storeMember1 = this.getOne(queryWrapper);
//            if (storeMember1 == null) {
//                baseCommonService.addLog("用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null);
//                return Result.error("token校验该用户不存在");
//            }
            //银行卡四要素认证(下发验证码)
            return this.bankCardFourAuthVerify(adminUserVO);
        } catch (Exception e) {
            return Result.error("请求失败");
        }

    }

    private Result<?> bankCardFourAuthVerify(AdminUserVO adminUserVO) {
        BankCardFourAuthVerifyRequest request = new BankCardFourAuthVerifyRequest();
        request.setCardNo(adminUserVO.getBackCard());
        request.setIdCard(adminUserVO.getCard());
        request.setRealName(adminUserVO.getName());
        request.setMobile(adminUserVO.getCardholderPhone());
        YzhResponse<BankCardFourAuthVerifyResponse> response = null;
        try {
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = clientBank.bankCardFourAuthVerify(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                BankCardFourAuthVerifyResponse data = response.getData();
                System.out.println("请求成功：" + data);
                baseCommonService.addLog("银行卡四要素认证(下发验证码)请求的唯一标识request-id： " + requestId, CommonConstant.LOG_TYPE_2, 2);
                return Result.ok(data);

            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + response.getMessage());
                baseCommonService.addLog("银行卡四要素认证(下发验证码)请求的唯一标识request-id： " + requestId + "发生异常：" + response.getCode() + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
                return Result.error("发生异常：" + response.getCode() + response.getMessage());
            }
        } catch (Exception e) {
            return Result.error("操作失败");
        }
    }


    @Override
    public Result<?> perfectInformationUpload(AdminUserVO adminUserVO, String authorization) {

        if (authorization.equals("")) {
            return Result.error("token不能为空");
        }
        String userPhone = JwtUtil.getUsername(authorization);
        //校验token==================
        if (!redisUtil.hasKey(CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone)) {
            return Result.error("TOKEN失效");
        }
        try {
            //1. 校验用户是否有效
            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone", userPhone);
            AdminUser storeMember1 = this.getOne(queryWrapper);
            if (storeMember1 == null) {
                baseCommonService.addLog("用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null);
                return Result.error("token校验该用户不存在");
            }
            QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
            adminCompSelectQueryWrapper.eq("phone", userPhone);
            adminCompSelectQueryWrapper.eq("sys_org_code", storeMember1.getSysOrgCode());
            AdminCompSelect one = adminCompSelectService.getOne(adminCompSelectQueryWrapper);
            if (null != one) {
                storeMember1.setYzh(one.getYzh());

            }

            String yzh = storeMember1.getYzh();
            if ("1".equals(yzh)) {
                //银行卡四要素认证(上传验证码)
                return this.bankCardFourAuthConfirm(adminUserVO, storeMember1);
            } else {
                this.saveAdminUserVO(adminUserVO, storeMember1);
                return Result.ok("操作成功");
            }

        } catch (Exception e) {
            return Result.error("请求失败");
        }

    }

    @Override
    public Result<?> getApiUserSignStatus(String authorization) {
        if (authorization.equals("")) {
            return Result.error("token不能为空");
        }
        String userPhone = JwtUtil.getUsername(authorization);
        //校验token==================
        if (!redisUtil.hasKey(CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone)) {
            return Result.error("TOKEN失效");
        }
        try {
            //1. 校验用户是否有效
            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone", userPhone);
            AdminUser storeMember1 = this.getOne(queryWrapper);
            if (storeMember1 == null) {
                baseCommonService.addLog("用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null);
                return Result.error("token校验该用户不存在");
            }
            GetApiUserSignStatusRequest request = new GetApiUserSignStatusRequest();
            request.setDealerId(dealer_id);
            request.setBrokerId(broker_id);
            request.setRealName(storeMember1.getName());
            request.setIdCard(storeMember1.getCard());
            YzhResponse<GetApiUserSignStatusResponse> response = null;
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = client.getApiUserSignStatus(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                GetApiUserSignStatusResponse data = response.getData();
                System.out.println("请求成功：" + data);
                baseCommonService.addLog("用户签约状态请求的唯一标识request-id： " + requestId, CommonConstant.LOG_TYPE_2, 2);

                return Result.ok(data);
            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + response.getMessage());
                baseCommonService.addLog("用户签约状态请求的唯一标识request-id： " + requestId + "发生异常：" + response.getCode() + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
                return Result.error("发生异常：" + response.getCode() + response.getMessage());
            }

        } catch (Exception e) {
            return Result.error("请求失败");
        }
    }

    @Override
    public void updateByUser(AdminUser adminUser) {
        String phone = adminUser.getPhone();

        AdminCompSelect adminCompSelect = adminCompSelectService.getById(adminUser.getId());
        adminCompSelect.setKsName(adminUser.getKsname());
        adminCompSelect.setDwName(adminUser.getDwname());
        adminCompSelect.setAvatar(adminUser.getAvatar());
        adminCompSelect.setCardPic(adminUser.getCardPic());
        adminCompSelect.setName(adminUser.getName());
        adminCompSelect.setWisWjdc(adminUser.getWisWjdc());
        adminCompSelect.setAllocationNum(adminUser.getAllocationNum());
        adminCompSelect.setWisMhu(adminUser.getWisMhu());
        adminCompSelectService.updateById(adminCompSelect);


    }

    @Override
    public Result<?> saveMain(AdminUser adminUser) {
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        adminUser.setCompName(user.getRealname());
        String phone = adminUser.getPhone();
        String compName = adminUser.getCompName();
        adminUser.setDoctorAndSpecialist("2");
        String salt = oConvertUtils.randomGen(8);
        adminUser.setSalt(salt);
        if (adminUser.getPassword() == null) {
            adminUser.setPassword("123456");
        }
        if (adminUser.getPassword().equals("")) {
            adminUser.setPassword("123456");
        }
        adminUser.setWisMhu("允许");
        adminUser.setCompleteInformation(1);
        adminUser.setIsTrue("1");
        adminUser.setSysOrgCode(user.getOrgCode());
        adminUser.setYzh(user.getYzh());
        adminUser.setWisWjdc("允许");
        String passwordEncode = PasswordUtil.encrypt(adminUser.getPhone(), adminUser.getPassword(), salt);
        adminUser.setPassword(passwordEncode);


        QueryWrapper<AdminUser> adminUserQueryWrapper = new QueryWrapper<>();
        adminUserQueryWrapper.eq("phone", phone);
//        adminUserQueryWrapper.eq("doctor_and_specialist", "2");
        AdminUser adminUsers = adminUserService.getOne(adminUserQueryWrapper);

        if (null != adminUsers) {

            AdminCompSelect adminCompSelect = new AdminCompSelect();
            adminCompSelect.setOrderId(adminUsers.getId());
            adminCompSelect.setPhone(phone);
            adminCompSelect.setCompName(compName);
            adminCompSelect.setSysOrgCode(adminUser.getSysOrgCode());
            adminCompSelect.setKsName(adminUser.getKsname());
            adminCompSelect.setDwName(adminUser.getDwname());
            adminCompSelect.setAvatar(adminUser.getAvatar());
            adminCompSelect.setCardPic(adminUser.getCardPic());
            adminCompSelect.setDoctorAndSpecialist("2");
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setYzh(user.getYzh());
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setWisMhu("允许");
            adminCompSelect.setWisWjdc("允许");
            adminCompSelect.setName(adminUser.getName());
            adminCompSelect.setYzh(user.getYzh());

            QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
            adminCompSelectQueryWrapper.eq("phone", phone);
            adminCompSelectQueryWrapper.eq("comp_name", compName);
            adminCompSelectQueryWrapper.eq("sys_org_code", adminUser.getSysOrgCode());
//            adminCompSelectQueryWrapper.eq("doctor_and_specialist", "2");
            List<AdminCompSelect> list = adminCompSelectService.list(adminCompSelectQueryWrapper);

            if (null != list && list.size() > 0) {
                return Result.error("该手机号已存在该公司,请更换手机号进行注册");
            } else {
                adminCompSelectService.save(adminCompSelect);
            }
        } else {
            adminUser.setId(UUID.randomUUID().toString().replace("-", ""));

            AdminCompSelect adminCompSelect = new AdminCompSelect();
            adminCompSelect.setOrderId(adminUser.getId());
            adminCompSelect.setPhone(phone);
            adminCompSelect.setCompName(compName);
            adminCompSelect.setSysOrgCode(adminUser.getSysOrgCode());
            adminCompSelect.setKsName(adminUser.getKsname());
            adminCompSelect.setDwName(adminUser.getDwname());
            adminCompSelect.setAvatar(adminUser.getAvatar());
            adminCompSelect.setCardPic(adminUser.getCardPic());
            adminCompSelect.setDoctorAndSpecialist("2");
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setYzh(user.getYzh());
            adminCompSelect.setCompleteInformation(1);
            adminCompSelect.setWisMhu("允许");
            adminCompSelect.setWisWjdc("允许");
            adminCompSelect.setName(adminUser.getName());
            adminCompSelect.setYzh(user.getYzh());

            QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
            adminCompSelectQueryWrapper.eq("phone", phone);
            adminCompSelectQueryWrapper.eq("comp_name", compName);
            adminCompSelectQueryWrapper.eq("sys_org_code", adminUser.getSysOrgCode());
//            adminCompSelectQueryWrapper.eq("doctor_and_specialist", "2");
            List<AdminCompSelect> list = adminCompSelectService.list(adminCompSelectQueryWrapper);

            if (null != list && list.size() > 0) {
                return Result.error("该手机号已存在该公司,请更换手机号进行注册");
            } else {
                adminCompSelectService.save(adminCompSelect);
            }
            adminUser.setName("");
            adminUser.setDwname("");
            adminUser.setKsname("");
            adminUser.setCardPic("");

            this.save(adminUser);

        }
        return Result.OK("操作成功");
    }

    private Result<?> bankCardFourAuthConfirm(AdminUserVO adminUserVO, AdminUser adminUser) {
        BankCardFourAuthConfirmRequest request = new BankCardFourAuthConfirmRequest();
        request.setCardNo(adminUserVO.getBackCard());
        request.setIdCard(adminUserVO.getCard());
        request.setRealName(adminUserVO.getName());
        request.setMobile(adminUserVO.getCardholderPhone());
        request.setCaptcha(adminUserVO.getCode());
        request.setRef(adminUserVO.getRef());
        YzhResponse<BankCardFourAuthConfirmResponse> response = null;


        try {
            String requestId = BaseUtil.getRandomStr("requestId");
            // request-id：每次请求的唯一标识
            // 强烈建议平台企业自定义 request-id 并记录在日志中，如遇异常请求，便于使用 request-id 追踪问题
            // 如未自定义则使用 SDK 中的 UUID 方法自动生成，注意：UUID 方法不能保证全局唯一，可能会出现 ID 重复，推荐自行实现全局唯一 ID
            response = clientBank.bankCardFourAuthConfirm(YzhRequest.build(requestId, request));
            if (response.isSuccess()) {// 请求成功
                BankCardFourAuthConfirmResponse data = response.getData();
                baseCommonService.addLog("银行卡四要素认证(上传验证码)请求的唯一标识request-id： " + requestId, CommonConstant.LOG_TYPE_2, 2);
                System.out.println("请求成功：" + data);
                this.saveAdminUserVO(adminUserVO, adminUser);
                return Result.ok("请求成功：" + data);

            } else {
                System.out.println("HTTP Status Code：" + response.getHttpCode());
                System.out.println("发生异常：" + response.getCode() + response.getMessage());
                baseCommonService.addLog("银行卡四要素认证(上传验证码)请求的唯一标识request-id： " + requestId + "发生异常：" + response.getCode() + response.getMessage(), CommonConstant.LOG_TYPE_2, 2);
                return Result.error("发生异常：" + response.getCode() + response.getMessage());
            }
        } catch (Exception e) {
            return Result.error("请求失败");
        }
    }

    public void saveAdminUserVO(AdminUserVO adminUserVO, AdminUser adminUser) {

        String sysOrgCode = adminUser.getSysOrgCode();

        QueryWrapper<AdminUser> adminUserQueryWrapper = new QueryWrapper<>();
        adminUserQueryWrapper.eq("phone", adminUser.getPhone());
        adminUserQueryWrapper.eq("sys_org_code", sysOrgCode);

        AdminUser one = adminUserService.getOne(adminUserQueryWrapper);
        if (null != one) {

            one.setDoctorAndSpecialist(adminUserVO.getDoctorAndSpecialist());

            this.updateById(one);
        }
        QueryWrapper<AdminCompSelect> adminCompSelectQueryWrapper = new QueryWrapper<>();
        adminCompSelectQueryWrapper.eq("phone", adminUser.getPhone());
        adminCompSelectQueryWrapper.eq("sys_org_code", sysOrgCode);
        AdminCompSelect adminCompSelect = adminCompSelectService.getOne(adminCompSelectQueryWrapper);
        if (null != adminCompSelect) {
            adminCompSelect.setCard(adminUserVO.getCard());
            adminCompSelect.setCardholderName(adminUserVO.getName());
            adminCompSelect.setBackCard(adminUserVO.getBackCard());
            adminCompSelect.setCardholderPhone(adminUserVO.getCardholderPhone());
            adminCompSelect.setDwName(adminUserVO.getDwname());
            adminCompSelect.setKsName(adminUserVO.getKsname());
            adminCompSelect.setCompleteInformation(2);
            adminCompSelect.setDoctorAndSpecialist(adminUserVO.getDoctorAndSpecialist());
            adminCompSelect.setCardPic(adminUserVO.getCardPic());
            adminCompSelectService.updateById(adminCompSelect);
        }


    }

    @Override
    public void updateByUser2(AdminUser adminUser) {
        AdminCompSelect adminCompSelect = adminCompSelectService.getById(adminUser.getId());
        adminCompSelect.setKsName(adminUser.getKsname());
        adminCompSelect.setDwName(adminUser.getDwname());
        adminCompSelect.setAvatar(adminUser.getAvatar());
        adminCompSelect.setCardPic(adminUser.getCardPic());
        adminCompSelect.setName(adminUser.getName());
        adminCompSelect.setAllocationNum(adminUser.getAllocationNum());
        adminCompSelect.setWisWjdc(adminUser.getWisWjdc());
        adminCompSelect.setWisMhu(adminUser.getWisMhu());
        adminCompSelectService.updateById(adminCompSelect);

    }

    private BatchOrderInfo[] getBatchOrderInfoList(AdminUser adminUser1) {
        String id = adminUser1.getId();
        AdminCompSelect adminCompSelect = adminCompSelectService.getById(id);

        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Date date = new Date();
        String format = sdf.format(date);
        Random random = new Random();
        int randomNumber = random.nextInt(900000) + 100000;

        BatchOrderInfo info1 = new BatchOrderInfo();
        info1.setOrderId("BL" + format + randomNumber);
        info1.setRealName(adminCompSelect.getCardholderName());
        info1.setIdCard(adminCompSelect.getCard());
        info1.setCardNo(adminCompSelect.getBackCard());
        info1.setOpenid("");
        info1.setPhoneNo(adminCompSelect.getCardholderPhone());
        info1.setProjectId("");
        info1.setPay(String.valueOf(adminUser1.getMoney()));
        info1.setPayRemark(adminUser1.getNotes());
//        测试回调地址
//        info1.setNotifyUrl("http://59.110.230.108:10001/adminDoctorUser/adminUser/notifyUrl");
//        正式回调地址
//        info1.setNotifyUrl("http://47.96.249.184:10001/adminDoctorUser/adminUser/notifyUrl");
//        传空字符串 使用云账户综合服务平台配置的接口回调地址
        info1.setNotifyUrl("");


        BatchOrderInfo[] infoArry = new BatchOrderInfo[1];
        infoArry[0] = info1;

        return infoArry;

    }
}
