package org.jeecg.modules.quesmanage.controller;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.checkerframework.checker.units.qual.A;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.quesmanage.entity.QuesExamManage;
import org.jeecg.modules.quesmanage.service.IQuesExamManageService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.modules.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

/**
 * @Description: 问卷题库管理
 * @Author: jeecg-boot
 * @Date: 2023-06-15
 * @Version: V1.0
 */
@Api(tags = "问卷题库管理")
@RestController
@RequestMapping("/QuesExamManage/quesExamManage")
@Slf4j
public class QuesExamManageController extends JeecgController<QuesExamManage, IQuesExamManageService> {
    @Autowired
    private IQuesExamManageService quesExamManageService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 分页列表查询
     *
     * @param quesExamManage
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "问卷题库管理-分页列表查询")
    @ApiOperation(value = "问卷题库管理-分页列表查询", notes = "问卷题库管理-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<QuesExamManage>> queryPageList(QuesExamManage quesExamManage,
                                                       @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                       @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                       HttpServletRequest req, String examName) {
        QueryWrapper<QuesExamManage> queryWrapper = QueryGenerator.initQueryWrapper(quesExamManage, req.getParameterMap());

        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")){
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }
        queryWrapper.orderByDesc("create_time");
        Page<QuesExamManage> page = new Page<QuesExamManage>(pageNo, pageSize);
        IPage<QuesExamManage> pageList = quesExamManageService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param quesExamManage
     * @return
     */
    @AutoLog(value = "问卷题库管理-添加")
    @ApiOperation(value = "问卷题库管理-添加", notes = "问卷题库管理-添加")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody QuesExamManage quesExamManage) {
        quesExamManageService.save(quesExamManage);
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param quesExamManage
     * @return
     */
    @AutoLog(value = "问卷题库管理-编辑")
    @ApiOperation(value = "问卷题库管理-编辑", notes = "问卷题库管理-编辑")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody QuesExamManage quesExamManage) {
        quesExamManageService.updateMessage(quesExamManage);
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "问卷题库管理-通过id删除")
    @ApiOperation(value = "问卷题库管理-通过id删除", notes = "问卷题库管理-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        quesExamManageService.removeById(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "问卷题库管理-批量删除")
    @ApiOperation(value = "问卷题库管理-批量删除", notes = "问卷题库管理-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.quesExamManageService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功!");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "问卷题库管理-通过id查询")
    @ApiOperation(value = "问卷题库管理-通过id查询", notes = "问卷题库管理-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<QuesExamManage> queryById(@RequestParam(name = "id", required = true) String id) {
        QuesExamManage quesExamManage = quesExamManageService.getById(id);
        if (quesExamManage == null) {
            return Result.error("未找到对应数据", null);
        }
        return Result.OK(quesExamManage);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param quesExamManage
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, QuesExamManage quesExamManage) {
        return super.exportXls(request, quesExamManage, QuesExamManage.class, "问卷题库管理");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, QuesExamManage.class);
    }

}
