package org.jeecg.modules.quesmanage.controller;

import java.io.UnsupportedEncodingException;
import java.io.IOException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPatch;
import org.jeecg.modules.quesmanage.mapper.QuesManageMapper;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.vo.LoginUser;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.quesmanage.entity.QuesManageDetail;
import org.jeecg.modules.quesmanage.entity.QuesManage;
import org.jeecg.modules.quesmanage.vo.QuesManagePage;
import org.jeecg.modules.quesmanage.service.IQuesManageService;
import org.jeecg.modules.quesmanage.service.IQuesManageDetailService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import sun.java2d.pipe.SpanIterator;

/**
 * @Description: 问卷管理
 * @Author: jeecg-boot
 * @Date: 2023-06-15
 * @Version: V1.0
 */
@Api(tags = "问卷管理")
@RestController
@RequestMapping("/quesmanage/quesManage")
@Slf4j
public class QuesManageController {
    @Autowired
    private IQuesManageService quesManageService;
    @Autowired
    private IQuesManageDetailService quesManageDetailService;
    @Autowired
    private QuesManageMapper quesManageMapper;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 分页列表查询
     *
     * @param quesManage
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "问卷管理-分页列表查询")
    @ApiOperation(value = "问卷管理-分页列表查询", notes = "问卷管理-分页列表查询")
    @GetMapping(value = "/list")
    public Result<?> queryPageList(QuesManage quesManage,
                                   @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                   @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                   HttpServletRequest req) {
        QueryWrapper<QuesManage> queryWrapper = QueryGenerator.initQueryWrapper(quesManage, req.getParameterMap());

        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")){
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }


        Page<QuesManage> page = new Page<QuesManage>(pageNo, pageSize);
        IPage<QuesManage> pageList = quesManageService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param quesManagePage
     * @return
     */
    @AutoLog(value = "问卷管理-添加")
    @ApiOperation(value = "问卷管理-添加", notes = "问卷管理-添加")
    @PostMapping(value = "/add")
    public Result<?> add(@RequestBody QuesManagePage quesManagePage) {
        quesManagePage.setIsDisable("1");
        quesManagePage.setDisable("0");
        QuesManage quesManage = new QuesManage();
        BeanUtils.copyProperties(quesManagePage, quesManage);
        quesManageService.saveMain(quesManage, quesManagePage.getQuesManageDetailList());
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param quesManagePage
     * @return
     */
    @AutoLog(value = "问卷管理-编辑")
    @ApiOperation(value = "问卷管理-编辑", notes = "问卷管理-编辑")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<?> edit(@RequestBody QuesManagePage quesManagePage) {
        QuesManage quesManage = new QuesManage();
        BeanUtils.copyProperties(quesManagePage, quesManage);
        QuesManage quesManageEntity = quesManageService.getById(quesManage.getId());
        if (quesManageEntity == null) {
            return Result.error("未找到对应数据");
        }
        quesManageService.updateMain(quesManage, quesManagePage.getQuesManageDetailList());
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "问卷管理-通过id删除")
    @ApiOperation(value = "问卷管理-通过id删除", notes = "问卷管理-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        quesManageService.delMain(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "问卷管理-批量删除")
    @ApiOperation(value = "问卷管理-批量删除", notes = "问卷管理-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<?> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.quesManageService.delBatchMain(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功！");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "问卷管理-通过id查询")
    @ApiOperation(value = "问卷管理-通过id查询", notes = "问卷管理-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<?> queryById(@RequestParam(name = "id", required = true) String id) {
        QuesManage quesManage = quesManageService.getById(id);
        if (quesManage == null) {
            return Result.error("未找到对应数据");
        }
        return Result.OK(quesManage);

    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "问卷管理详情通过主表ID查询")
    @ApiOperation(value = "问卷管理详情主表ID查询", notes = "问卷管理详情-通主表ID查询")
    @GetMapping(value = "/queryQuesManageDetailByMainId")
    public Result<?> queryQuesManageDetailListByMainId(@RequestParam(name = "id", required = true) String id) {
        List<QuesManageDetail> quesManageDetailList = quesManageDetailService.selectByMainId(id);
        return Result.OK(quesManageDetailList);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param quesManage
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, QuesManage quesManage) {
        // Step.1 组装查询条件查询数据
        QueryWrapper<QuesManage> queryWrapper = QueryGenerator.initQueryWrapper(quesManage, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        //Step.2 获取导出数据
        List<QuesManage> queryList = quesManageService.list(queryWrapper);
        // 过滤选中数据
        String selections = request.getParameter("selections");
        List<QuesManage> quesManageList = new ArrayList<QuesManage>();
        if (oConvertUtils.isEmpty(selections)) {
            quesManageList = queryList;
        } else {
            List<String> selectionList = Arrays.asList(selections.split(","));
            quesManageList = queryList.stream().filter(item -> selectionList.contains(item.getId())).collect(Collectors.toList());
        }

        // Step.3 组装pageList
        List<QuesManagePage> pageList = new ArrayList<QuesManagePage>();
        for (QuesManage main : quesManageList) {
            QuesManagePage vo = new QuesManagePage();
            BeanUtils.copyProperties(main, vo);
            List<QuesManageDetail> quesManageDetailList = quesManageDetailService.selectByMainId(main.getId());
            vo.setQuesManageDetailList(quesManageDetailList);
            pageList.add(vo);
        }

        // Step.4 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, "问卷管理列表");
        mv.addObject(NormalExcelConstants.CLASS, QuesManagePage.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("问卷管理数据", "导出人:" + sysUser.getRealname(), "问卷管理"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

//    /**
//     * 通过excel导入数据
//     *
//     * @param request
//     * @param response
//     * @return
//     */
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
//        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
//        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
//            MultipartFile file = entity.getValue();// 获取上传文件对象
//            ImportParams params = new ImportParams();
//            params.setTitleRows(2);
//            params.setHeadRows(1);
//            params.setNeedSave(true);
//            try {
//                List<QuesManagePage> list = ExcelImportUtil.importExcel(file.getInputStream(), QuesManagePage.class, params);
//                for (QuesManagePage page : list) {
//                    QuesManage po = new QuesManage();
//                    BeanUtils.copyProperties(page, po);
//                    quesManageService.saveMain(po, page.getQuesManageDetailList());
//                }
//                return Result.OK("文件导入成功！数据行数:" + list.size());
//            } catch (Exception e) {
//                log.error(e.getMessage(), e);
//                return Result.error("文件导入失败:" + e.getMessage());
//            } finally {
//                try {
//                    file.getInputStream().close();
//                } catch (IOException e) {
//                    e.printStackTrace();
//                }
//            }
//        }
//        return Result.OK("文件导入失败！");
//    }


    /**
     * 通过excel导入数据
     *
     * @param request
     * @param
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    @ApiOperation(value = "问卷导入", notes = "问卷导入Excel文件")
    public Result<?> importExcel(HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        //MultipartFile file = multipartRequest.getFile("file");
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();//上传文件
            try {
                Result result = quesManageService.importExcel(request, file);
                return result;
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.error("文件导入失败");
    }


    /**
     * 是否禁用问卷
     *
     * @param id
     * @return
     */
    @AutoLog(value = "问卷管理-编是否禁用问卷辑")
    @ApiOperation(value = "问卷管理-是否禁用问卷", notes = "问卷管理-是否禁用问卷")
    @RequestMapping(value = "/isDisable")
    public Result<?> isDisable(@RequestBody String id) {


        JSONObject jsonObject = (JSONObject) JSONObject.parse(id);
        String id1 = jsonObject.getString("id");
        String disable = jsonObject.getString("disable");
        QuesManage quesManageEntity = quesManageService.getById(id1);

        if ("1".equals(disable)) {
            quesManageEntity.setIsDisable("1");
            quesManageEntity.setDisable("0");
        } else if ("0".equals(disable)) {
            quesManageEntity.setIsDisable("0");
            quesManageEntity.setDisable("1");
        }
        quesManageMapper.updateById(quesManageEntity);
        Result<Object> ok = Result.OK("操作成功！");
        return ok;
    }

}
