package org.jeecg.modules.quesmanage.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sound.midi.Soundbank;

import net.sf.json.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.checkerframework.checker.units.qual.A;
import org.jeecg.modules.quesmanage.entity.QuesManageDetail;
import org.jeecg.modules.quesmanage.service.IQuesManageDetailService;
import org.jeecg.modules.quesmanage.service.IQuesManageService;
import org.jeecg.modules.quesmanage.vo.QuesSubNotePageExcel;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.vo.LoginUser;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.quesmanage.entity.QuesSubNodeMessage;
import org.jeecg.modules.quesmanage.entity.QuesSubNote;
import org.jeecg.modules.quesmanage.vo.QuesSubNotePage;
import org.jeecg.modules.quesmanage.service.IQuesSubNoteService;
import org.jeecg.modules.quesmanage.service.IQuesSubNodeMessageService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

/**
 * @Description: 提交记录列表
 * @Author: jeecg-boot
 * @Date: 2023-06-15
 * @Version: V1.0
 */
@Api(tags = "提交记录列表")
@RestController
@RequestMapping("/quessubnote/quesSubNote")
@Slf4j
public class QuesSubNoteController {
    @Autowired
    private IQuesSubNoteService quesSubNoteService;
    @Autowired
    private IQuesSubNodeMessageService quesSubNodeMessageService;
    @Autowired
    private ISysUserService sysUserService;


    /**
     * 分页列表查询
     *
     * @param quesSubNote
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "提交记录列表-分页列表查询")
    @ApiOperation(value = "提交记录列表-分页列表查询", notes = "提交记录列表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<?> queryPageList(QuesSubNote quesSubNote,
                                   @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                   @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                   HttpServletRequest req) {
        QueryWrapper<QuesSubNote> queryWrapper = QueryGenerator.initQueryWrapper(quesSubNote, req.getParameterMap());

        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        List<String> role = sysUserService.getRole(sysUser.getUsername());
        if (!role.contains("admin")){
            queryWrapper.eq("sys_org_code", sysUser.getOrgCode());
        }
        Page<QuesSubNote> page = new Page<QuesSubNote>(pageNo, pageSize);
        IPage<QuesSubNote> pageList = quesSubNoteService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param quesSubNotePage
     * @return
     */
    @AutoLog(value = "提交记录列表-添加")
    @ApiOperation(value = "提交记录列表-添加", notes = "提交记录列表-添加")
    @PostMapping(value = "/add")
    public Result<?> add(@RequestBody QuesSubNotePage quesSubNotePage) {
        QuesSubNote quesSubNote = new QuesSubNote();
        BeanUtils.copyProperties(quesSubNotePage, quesSubNote);
        quesSubNoteService.saveMain(quesSubNote, quesSubNotePage.getQuesSubNodeMessageList());
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param quesSubNotePage
     * @return
     */
    @AutoLog(value = "提交记录列表-编辑")
    @ApiOperation(value = "提交记录列表-编辑", notes = "提交记录列表-编辑")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<?> edit(@RequestBody QuesSubNotePage quesSubNotePage) {
        QuesSubNote quesSubNote = new QuesSubNote();
        BeanUtils.copyProperties(quesSubNotePage, quesSubNote);
        QuesSubNote quesSubNoteEntity = quesSubNoteService.getById(quesSubNote.getId());
        if (quesSubNoteEntity == null) {
            return Result.error("未找到对应数据");
        }
        quesSubNoteService.updateMain(quesSubNote, quesSubNotePage.getQuesSubNodeMessageList());
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "提交记录列表-通过id删除")
    @ApiOperation(value = "提交记录列表-通过id删除", notes = "提交记录列表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        quesSubNoteService.delMain(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "提交记录列表-批量删除")
    @ApiOperation(value = "提交记录列表-批量删除", notes = "提交记录列表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<?> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.quesSubNoteService.delBatchMain(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功！");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "提交记录列表-通过id查询")
    @ApiOperation(value = "提交记录列表-通过id查询", notes = "提交记录列表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<?> queryById(@RequestParam(name = "id", required = true) String id) {
        QuesSubNote quesSubNote = quesSubNoteService.getById(id);
        if (quesSubNote == null) {
            return Result.error("未找到对应数据");
        }
        return Result.OK(quesSubNote);

    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "提交记录列表详情通过主表ID查询")
    @ApiOperation(value = "提交记录列表详情主表ID查询", notes = "提交记录列表详情-通主表ID查询")
    @GetMapping(value = "/queryQuesSubNodeMessageByMainId")
    public Result<?> queryQuesSubNodeMessageListByMainId(@RequestParam(name = "id", required = true) String id) {
        List<QuesSubNodeMessage> quesSubNodeMessageList = quesSubNodeMessageService.selectByMainId(id);
        return Result.OK(quesSubNodeMessageList);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param quesSubNote
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, QuesSubNote quesSubNote) {
        // Step.1 组装查询条件查询数据
        QueryWrapper<QuesSubNote> queryWrapper = QueryGenerator.initQueryWrapper(quesSubNote, request.getParameterMap());
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        //Step.2 获取导出数据
        List<QuesSubNote> queryList = quesSubNoteService.list(queryWrapper);
        // 过滤选中数据
        String selections = request.getParameter("selections");
        List<QuesSubNote> quesSubNoteList = new ArrayList<QuesSubNote>();
        if (oConvertUtils.isEmpty(selections)) {
            quesSubNoteList = queryList;
        } else {
            List<String> selectionList = Arrays.asList(selections.split(","));
            quesSubNoteList = queryList.stream().filter(item -> selectionList.contains(item.getId())).collect(Collectors.toList());
        }

        // Step.3 组装pageList
        List<QuesSubNotePageExcel> pageList = new ArrayList<QuesSubNotePageExcel>();
        quesSubNodeMessageService.exportXls(pageList,quesSubNoteList);

        // Step.4 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        mv.addObject(NormalExcelConstants.FILE_NAME, "提交记录列表列表");
        mv.addObject(NormalExcelConstants.CLASS, QuesSubNotePageExcel.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("提交记录列表数据", "导出人:" + sysUser.getRealname(), "提交记录列表"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();// 获取上传文件对象
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<QuesSubNotePage> list = ExcelImportUtil.importExcel(file.getInputStream(), QuesSubNotePage.class, params);
                for (QuesSubNotePage page : list) {
                    QuesSubNote po = new QuesSubNote();
                    BeanUtils.copyProperties(page, po);
                    quesSubNoteService.saveMain(po, page.getQuesSubNodeMessageList());
                }
                return Result.OK("文件导入成功！数据行数:" + list.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.OK("文件导入失败！");
    }

}
