package org.jeecg.modules.quesmanage.service.impl;

import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.quesmanage.entity.*;
import org.jeecg.modules.quesmanage.mapper.*;
import org.jeecg.modules.quesmanage.service.IQuesManageDetailService;
import org.jeecg.modules.quesmanage.service.IQuesManageService;
import org.jeecg.modules.system.mapper.SysDictMapper;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.util.*;

/**
 * @Description: 问卷管理
 * @Author: jeecg-boot
 * @Date: 2023-06-15
 * @Version: V1.0
 */
@Service
public class QuesManageServiceImpl extends ServiceImpl<QuesManageMapper, QuesManage> implements IQuesManageService {

    @Autowired
    private QuesManageMapper quesManageMapper;
    @Autowired
    private QuesManageDetailMapper quesManageDetailMapper;
    @Autowired
    private IQuesManageDetailService quesManageDetailService;
    @Autowired
    private QuesSubNoteMapper quesSubNoteMapper;
    @Autowired
    private QuesExamManageMapper quesExamManageMapper;
    @Autowired
    private SysDictMapper sysDictMapper;

    @Override
    @Transactional
    public void saveMain(QuesManage quesManage, List<QuesManageDetail> quesManageDetailList) {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        quesManage.setId(UUID.randomUUID().toString().replace("-", ""));
        quesManageMapper.insert(quesManage);
        int i =1;
        if (quesManageDetailList != null && quesManageDetailList.size() > 0) {
            for (QuesManageDetail entity : quesManageDetailList) {
                //外键设置
                entity.setId(UUID.randomUUID().toString().replace("-", ""));
                entity.setOrderId(quesManage.getId());
                entity.setSortId(i);
                quesManageDetailMapper.insert(entity);
                //生成问卷同步到题库
                QuesExamManage quesExamManage = new QuesExamManage();
                quesExamManage.setId(UUID.randomUUID().toString().replace("-", ""));
                quesExamManage.setCreateBy(sysUser.getRealname());
                quesExamManage.setCreateTime(new Date());
                quesExamManage.setExamName(entity.getQuesName());
                quesExamManage.setExamAnswerA(entity.getAnswerA());
                quesExamManage.setExamAnswerB(entity.getAnswerB());
                quesExamManage.setExamAnswerC(entity.getAnswerC());
                quesExamManage.setExamAnswerD(entity.getAnswerD());
                quesExamManage.setExamAnswerE(entity.getAnswerE());
                quesExamManage.setExamAnswerF(entity.getAnswerF());
                quesExamManage.setExamAnswerG(entity.getAnswerG());
                quesExamManage.setExamType(entity.getQuesType());
                quesExamManage.setOrderId(entity.getId());
                quesExamManage.setSort(i);
                quesExamManageMapper.insert(quesExamManage);
                i++;

            }
        }
    }

    @Override
    @Transactional
    public void updateMain(QuesManage quesManage, List<QuesManageDetail> quesManageDetailList) {

        //1.先删除子表数据
        quesManageDetailMapper.deleteByMainId(quesManage.getId());

        //2.子表数据重新插入
        if (quesManageDetailList != null && quesManageDetailList.size() > 0) {
            for (QuesManageDetail quesManageDetail : quesManageDetailList) {
                //外键设置
                quesManageDetail.setOrderId(quesManage.getId());
                quesManageDetailMapper.insert(quesManageDetail);
            }
        }

        quesManageMapper.updateById(quesManage);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        if (quesManageDetailList != null && quesManageDetailList.size() > 0) {
            for (QuesManageDetail entity : quesManageDetailList) {
                String id = entity.getId();
                if (null == id) {
                    QuesManageDetail quesManageDetail = new QuesManageDetail();
                    quesManageDetail.setId(UUID.randomUUID().toString().replace("-", ""));
                    quesManageDetail.setCreateTime(new Date());
                    quesManageDetail.setUpdateTime(new Date());
                    quesManageDetail.setCreateBy(sysUser.getRealname());
                    quesManageDetail.setUpdateBy(sysUser.getRealname());
                    quesManageDetail.setQuesName(entity.getQuesName());
                    quesManageDetail.setQuesType(entity.getQuesType());
                    quesManageDetail.setAnswerA(entity.getAnswerA());
                    quesManageDetail.setAnswerB(entity.getAnswerB());
                    quesManageDetail.setAnswerC(entity.getAnswerC());
                    quesManageDetail.setAnswerD(entity.getAnswerD());
                    quesManageDetail.setAnswerE(entity.getAnswerE());
                    quesManageDetail.setAnswerF(entity.getAnswerF());
                    quesManageDetail.setAnswerG(entity.getAnswerG());
                    quesManageDetail.setOrderId(quesManage.getId());
                    quesManageDetailMapper.insert(quesManageDetail);
                    QuesExamManage quesExamManage = new QuesExamManage();
                    quesExamManage.setId(UUID.randomUUID().toString().replace("-", ""));
                    quesExamManage.setCreateTime(new Date());
                    quesExamManage.setUpdateTime(new Date());
                    quesExamManage.setCreateBy(sysUser.getRealname());
                    quesExamManage.setUpdateBy(sysUser.getRealname());
                    quesExamManage.setExamName(entity.getQuesName());
                    quesExamManage.setExamAnswerA(entity.getAnswerA());
                    quesExamManage.setExamAnswerB(entity.getAnswerB());
                    quesExamManage.setExamAnswerC(entity.getAnswerC());
                    quesExamManage.setExamAnswerD(entity.getAnswerD());
                    quesExamManage.setExamAnswerE(entity.getAnswerE());
                    quesExamManage.setExamAnswerF(entity.getAnswerF());
                    quesExamManage.setExamAnswerG(entity.getAnswerG());
                    quesExamManage.setExamType(entity.getQuesType());
                    quesExamManage.setOrderId(quesManageDetail.getId());
                    quesExamManageMapper.insert(quesExamManage);

                }
                QuesExamManage quesExamManage = quesExamManageMapper.getById(id);
                if (null != quesExamManage) {
                    quesExamManage.setExamName(entity.getQuesName());
                    quesExamManage.setExamAnswerA(entity.getAnswerA());
                    quesExamManage.setExamAnswerB(entity.getAnswerB());
                    quesExamManage.setExamAnswerC(entity.getAnswerC());
                    quesExamManage.setExamAnswerD(entity.getAnswerD());
                    quesExamManage.setExamAnswerE(entity.getAnswerE());
                    quesExamManage.setExamAnswerF(entity.getAnswerF());
                    quesExamManage.setExamAnswerG(entity.getAnswerG());
                    quesExamManage.setExamType(entity.getQuesType());
                    quesExamManageMapper.updateById(quesExamManage);
                }


            }
        }
    }

    @Override
    @Transactional
    public void delMain(String id) {
        quesManageDetailMapper.deleteByMainId(id);
        quesManageMapper.deleteById(id);
    }

    @Override
    @Transactional
    public void delBatchMain(Collection<? extends Serializable> idList) {
        for (Serializable id : idList) {
            quesManageDetailMapper.deleteByMainId(id.toString());
            quesManageMapper.deleteById(id);
        }
    }

    @Override
    public Result importExcel(HttpServletRequest request, MultipartFile uploadFile) throws IOException {
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        // 获取文件名
        String originalFilename = uploadFile.getOriginalFilename();
        InputStream inputStream = uploadFile.getInputStream();
        Workbook workbook = null;
        if (originalFilename.endsWith(".xls")) {
            // excel 2003
            workbook = new HSSFWorkbook(inputStream);
        } else if (originalFilename.endsWith(".xlsx")) {
            // excel 2007~
            workbook = new XSSFWorkbook(inputStream);
        } else {
            return Result.error("文件格式错误，请重新检查");
        }
        // 获取Sheet
        ArrayList<QuesManageDetail> quesManageDetailList = new ArrayList<>();
        for (int i = 0; i < 1; i++) {

            Sheet sheetAt = workbook.getSheetAt(i);
            //创建主表信息
            QuesManage quesManage = new QuesManage();
            quesManage.setId(UUID.randomUUID().toString().replace("-", ""));
            quesManage.setCreateTime(new Date());
            quesManage.setCreateBy(sysUser.getRealname());
            quesManage.setIsDisable("1");
            quesManage.setDisable("0");
            String quesName = sheetAt.getRow(1).getCell(1).toString();
            String quesMessage = sheetAt.getRow(2).getCell(1).toString();
            if (StringUtils.isBlank(quesName)) {
                return Result.error("请填写问卷名称");
            }
            if (StringUtils.isBlank(quesMessage)) {
                return Result.error("请填写问卷描述");
            }
            quesManage.setQuesName(quesName);
            quesManage.setQuesMessage(quesMessage);

            for (int a = 4; a <= sheetAt.getLastRowNum(); a++) {

                Row row = sheetAt.getRow(a);
                String quesType = row.getCell(0).toString();//题目类型
                String sysDict = sysDictMapper.getCodebyName("ques_type", quesType);
                if (null == sysDict) {
                    return Result.error("题目类型不存在，请前往系统管理数据字典添加题目类型！");
                }

                String ques = row.getCell(1).toString();//题干
                if (null == row.getCell(2)) {
                    if (null == row.getCell(2)) {
                        this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                                null, null, null, null, null, null, null, null, null);
                    }
                    continue;
                }
                String answerA = row.getCell(2).toString();//答案A

                if (null == row.getCell(3)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, null, null, null, null, null, null, null, null);
                    continue;
                }
                String answerB = row.getCell(3).toString();//答案B

                if (null == row.getCell(4)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, null, null, null, null, null, null, null);
                    continue;
                }
                String answerC = row.getCell(4).toString();//答案C

                if (null == row.getCell(5)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, answerC, null, null, null, null, null, null);
                    continue;
                }
                String answerD = row.getCell(5).toString();//答案D

                if (null == row.getCell(5)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, answerC, answerD, null, null, null, null, null);
                    continue;
                }
                String answerE = row.getCell(6).toString();//答案E

                if (null == row.getCell(6)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, answerC, answerD, answerE, null, null, null, null);
                    continue;
                }
                String answerF = row.getCell(7).toString();//答案F

                if (null == row.getCell(8)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, answerC, answerD, answerE, answerF, null, null, null);
                    continue;
                }
                String answerG = row.getCell(8).toString();//答案G

                if (null == row.getCell(9)) {
                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
                            answerA, answerB, answerC, answerD, answerE, answerF, answerG, null, null);
                    continue;
                }
//                String answerH = row.getCell(9).toString();//答案H
//
//                if (null == row.getCell(10)) {
//                    this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
//                            answerA, answerB, answerC, answerD, answerE, answerF, answerG, answerH, null);
//                    continue;
//                }
//                String answerI = row.getCell(10).toString();//答案I
//                this.saveMessageDetail(quesManage.getId(), sysUser, quesManageDetailList, ques, sysDict,
//                        answerA, answerB, answerC, answerD, answerE, answerF, answerG, answerH, answerI);

            }
            this.saveMain(quesManage, quesManageDetailList);
        }
        return Result.ok("导入成功");
    }

    private List<QuesManageDetail> saveMessageDetail(String id, LoginUser sysUser, ArrayList<QuesManageDetail> quesManageDetailList, String ques, String sysDict,
                                                     String answerA, String answerB, String answerC, String answerD, String answerE, String answerF, String answerG, String answerH, String answerI) {

        QuesManageDetail quesManageDetail = new QuesManageDetail();
        quesManageDetail.setId(UUID.randomUUID().toString().replace("-", ""));
        quesManageDetail.setCreateTime(new Date());
        quesManageDetail.setCreateBy(sysUser.getRealname());
        quesManageDetail.setOrderId(id);
        quesManageDetail.setQuesName(ques);
        quesManageDetail.setQuesType(sysDict);

        JSONObject answeraJson = new JSONObject();
        answeraJson.put("A", answerA);
        answeraJson.put("B", answerB);
        answeraJson.put("C", answerC);
        answeraJson.put("D", answerD);
        answeraJson.put("E", answerE);
        answeraJson.put("F", answerF);
        answeraJson.put("G", answerG);
//        answeraJson.put("H", answerH);
//        answeraJson.put("I", answerI);
//        String answeraJsonToString = answeraJson.toString().replace("{", "").replace("\"", "").replace("}", "");
//        System.out.println(answeraJsonToString);
        quesManageDetail.setAnswerA(answerA);
        quesManageDetail.setAnswerB(answerB);
        quesManageDetail.setAnswerC(answerC);
        quesManageDetail.setAnswerD(answerD);
        quesManageDetail.setAnswerE(answerE);
        quesManageDetail.setAnswerF(answerF);
        quesManageDetail.setAnswerG(answerG);
        quesManageDetailList.add(quesManageDetail);
        return quesManageDetailList;
    }


}
