package org.jeecg.modules.quesmanage.service.impl;

import org.jeecg.modules.quesmanage.entity.QuesSubNote;
import org.jeecg.modules.quesmanage.entity.QuesSubNodeMessage;
import org.jeecg.modules.quesmanage.mapper.QuesSubNodeMessageMapper;
import org.jeecg.modules.quesmanage.mapper.QuesSubNoteMapper;
import org.jeecg.modules.quesmanage.service.IQuesSubNoteService;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import java.io.Serializable;
import java.util.List;
import java.util.Collection;
import java.util.UUID;

/**
 * @Description: 提交记录列表
 * @Author: jeecg-boot
 * @Date:   2023-06-15
 * @Version: V1.0
 */
@Service
public class QuesSubNoteServiceImpl extends ServiceImpl<QuesSubNoteMapper, QuesSubNote> implements IQuesSubNoteService {

	@Autowired
	private QuesSubNoteMapper quesSubNoteMapper;
	@Autowired
	private QuesSubNodeMessageMapper quesSubNodeMessageMapper;
	
	@Override
	@Transactional
	public void saveMain(QuesSubNote quesSubNote, List<QuesSubNodeMessage> quesSubNodeMessageList) {
		quesSubNoteMapper.insert(quesSubNote);
		if(quesSubNodeMessageList!=null && quesSubNodeMessageList.size()>0) {
			for(QuesSubNodeMessage entity:quesSubNodeMessageList) {
				//外键设置
				entity.setId(UUID.randomUUID().toString().replace("-",""));
				entity.setOrderId(quesSubNote.getId());
				quesSubNodeMessageMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional
	public void updateMain(QuesSubNote quesSubNote,List<QuesSubNodeMessage> quesSubNodeMessageList) {
		quesSubNoteMapper.updateById(quesSubNote);
		
		//1.先删除子表数据
		quesSubNodeMessageMapper.deleteByMainId(quesSubNote.getId());
		
		//2.子表数据重新插入
		if(quesSubNodeMessageList!=null && quesSubNodeMessageList.size()>0) {
			for(QuesSubNodeMessage entity:quesSubNodeMessageList) {
				//外键设置
				entity.setOrderId(quesSubNote.getId());
				quesSubNodeMessageMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional
	public void delMain(String id) {
		quesSubNodeMessageMapper.deleteByMainId(id);
		quesSubNoteMapper.deleteById(id);
	}

	@Override
	@Transactional
	public void delBatchMain(Collection<? extends Serializable> idList) {
		for(Serializable id:idList) {
			quesSubNodeMessageMapper.deleteByMainId(id.toString());
			quesSubNoteMapper.deleteById(id);
		}
	}
	
}
