package org.jeecg.modules.sysusercompany.controller;

import java.net.SocketTimeoutException;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.shiro.SecurityUtils;
import org.checkerframework.checker.units.qual.A;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.system.entity.SysUser;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecg.modules.sysusercompany.entity.SysUserCompany;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.modules.sysusercompany.service.ISysUserCompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 公司用户管理
 * @Author: jeecg-boot
 * @Date:   2023-06-29
 * @Version: V1.0
 */
@Api(tags="公司用户管理")
@RestController
@RequestMapping("/SysUserCompany/sysUserCompany")
@Slf4j
public class SysUserCompanyController extends JeecgController<SysUserCompany, ISysUserCompanyService> {
	@Autowired
	private ISysUserCompanyService sysUserCompanyService;
	@Autowired
	private ISysUserService sysUserService;

	/**
	 * 分页列表查询
	 *
	 * @param sysUserCompany
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "公司用户管理-分页列表查询")
	@ApiOperation(value="公司用户管理-分页列表查询", notes="公司用户管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<SysUserCompany>> queryPageList(SysUserCompany sysUserCompany,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<SysUserCompany> queryWrapper = QueryGenerator.initQueryWrapper(sysUserCompany, req.getParameterMap());
		LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		List<String> role = sysUserService.getRole(sysUser.getUsername());
		if (!role.contains("admin")){
			queryWrapper.eq("company_code", sysUser.getOrgCode());
		}

		Page<SysUserCompany> page = new Page<SysUserCompany>(pageNo, pageSize);
		IPage<SysUserCompany> pageList = sysUserCompanyService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param sysUserCompany
	 * @return
	 */
	@AutoLog(value = "公司用户管理-添加")
	@ApiOperation(value="公司用户管理-添加", notes="公司用户管理-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody SysUserCompany sysUserCompany) {

		return sysUserCompanyService.saveMain(sysUserCompany) ;
	}

	/**
	 *  编辑
	 *
	 * @param sysUserCompany
	 * @return
	 */
	@AutoLog(value = "公司用户管理-编辑")
	@ApiOperation(value="公司用户管理-编辑", notes="公司用户管理-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody SysUserCompany sysUserCompany) {
		sysUserCompanyService.updateMain(sysUserCompany);
		return Result.OK("编辑成功!");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "公司用户管理-通过id删除")
	@ApiOperation(value="公司用户管理-通过id删除", notes="公司用户管理-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		SysUserCompany byId = sysUserCompanyService.getById(id);
		String companyCode = byId.getCompanyCode();
		SysUser userbyUsername = sysUserService.getUserbyUsername(companyCode);
		sysUserService.deleteUser(userbyUsername.getId());
		sysUserCompanyService.removeById(id);
		return Result.OK("删除成功!");
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "公司用户管理-批量删除")
	@ApiOperation(value="公司用户管理-批量删除", notes="公司用户管理-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		List<String> strings = Arrays.asList(ids.split(","));
		for (String id:strings){
			SysUserCompany byId = sysUserCompanyService.getById(id);
			String companyCode = byId.getCompanyCode();
			SysUser userbyUsername = sysUserService.getUserbyUsername(companyCode);
			sysUserService.deleteUser(userbyUsername.getId());
		}
		this.sysUserCompanyService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "公司用户管理-通过id查询")
	@ApiOperation(value="公司用户管理-通过id查询", notes="公司用户管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<SysUserCompany> queryById(@RequestParam(name="id",required=true) String id) {
		SysUserCompany sysUserCompany = sysUserCompanyService.getById(id);
		if(sysUserCompany==null) {
			return Result.error("未找到对应数据",null);
		}
		return Result.OK(sysUserCompany);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param sysUserCompany
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, SysUserCompany sysUserCompany) {
        return super.exportXls(request, sysUserCompany, SysUserCompany.class, "公司用户管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, SysUserCompany.class);
    }

}
