package org.jeecg.modules.sysusercompany.service.impl;

import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.util.PasswordUtil;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.system.entity.SysUser;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecg.modules.sysusercompany.entity.SysUserCompany;
import org.jeecg.modules.sysusercompany.mapper.SysUserCompanyMapper;
import org.jeecg.modules.sysusercompany.service.ISysUserCompanyService;
import org.jeecg.modules.utils.pinyinUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.Locale;

/**
 * @Description: 公司用户管理
 * @Author: jeecg-boot
 * @Date: 2023-06-29
 * @Version: V1.0
 */
@Service
public class SysUserCompanyServiceImpl extends ServiceImpl<SysUserCompanyMapper, SysUserCompany> implements ISysUserCompanyService {

    @Autowired
    private SysUserCompanyMapper sysUserCompanyMapper;

    @Autowired
    private ISysUserService sysUserService;

    @Override
    @Transactional
    public Result saveMain(SysUserCompany sysUserCompany) {
        String companyName = sysUserCompany.getCompanyName();
        String companyCode = sysUserCompany.getCompanyCode();
        String password = sysUserCompany.getPassword();
        String yzh = sysUserCompany.getYzh();


        SysUser user = new SysUser();
        String pinYinHeadChar = pinyinUtil.getPinYinHeadChar(companyName);
        String s = pinYinHeadChar.toUpperCase(Locale.forLanguageTag(pinYinHeadChar));
        user.setOrgCode(s);
        user.setUsername(companyCode);
        user.setRealname(companyName);
        user.setCreateTime(new Date());//设置创建时间
        String salt = oConvertUtils.randomGen(8);
        user.setSalt(salt);
        String passwordEncode = PasswordUtil.encrypt(companyCode, password, salt);
        user.setPassword(passwordEncode);
        user.setStatus(1);
        user.setYzh(yzh);
        user.setDelFlag(CommonConstant.DEL_FLAG_0);


        sysUserCompany.setCompanyCode(companyCode);
        sysUserCompany.setPassword(passwordEncode);
        sysUserCompany.setCompanyName(companyName);


        SysUserCompany userCompany = sysUserCompanyMapper.getCompany(sysUserCompany.getCompanyName(), sysUserCompany.getCompanyCode());
        if (null != userCompany) {
            return Result.error("公司已经存在，请勿重复添加");
        }
        // 保存用户走一个service 保证事务
        sysUserService.saveUser(user, "1671322266401476610", null);
        sysUserCompanyMapper.insert(sysUserCompany);

        return Result.OK("操作成功");
    }

    @Override
    @Transactional
    public Result updateMain(SysUserCompany sysUserCompany) {

        String companyName = sysUserCompany.getCompanyName();
        String companyCode = sysUserCompany.getCompanyCode();
        String password = sysUserCompany.getPassword();
        String yzh = sysUserCompany.getYzh();

        String id = sysUserCompany.getId();
        SysUserCompany byId = this.getById(id);
        String companyCode1 = byId.getCompanyCode();

        if (!password.equals(byId.getPassword())) {
            SysUser user = sysUserService.getUserbyUsername(companyCode1);
            String salt = oConvertUtils.randomGen(8);
            user.setSalt(salt);
            String passwordEncode = PasswordUtil.encrypt(companyCode, password, salt);
            sysUserCompany.setPassword(passwordEncode);
            user.setYzh(yzh);
            user.setRealname(companyName);
            user.setUsername(companyCode);
            user.setPassword(passwordEncode);
            sysUserService.editUser(user, "1671322266401476610", null);

        }

        sysUserCompany.setCompanyName(companyName);
        sysUserCompany.setCompanyCode(companyCode);


        sysUserCompanyMapper.updateById(sysUserCompany);


        return Result.ok("操作成功");
    }
}
