package org.jeecg.modules.utils;

import org.apache.http.NameValuePair;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.conn.ssl.NoopHostnameVerifier;
import org.apache.http.conn.ssl.TrustStrategy;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.impl.conn.PoolingHttpClientConnectionManager;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.ssl.SSLContexts;
import org.apache.http.util.EntityUtils;

import javax.net.ssl.SSLContext;
import java.io.IOException;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 描述 用于发送http请求的工具类
 *
 * @author zuoxd
 * @ClassName: HttpClientUtil
 * @date 2017-8-11 下午1:34:17
 */
public class HttpClientUtil {

    private static CloseableHttpClient httpClient;
    private static PoolingHttpClientConnectionManager connMgr;
    private static RequestConfig requestConfig;
    private static final int MAX_TIMEOUT = 7000;

    static {
        init();
        closeExpiredConnectionsPeriodTask(60);
    }

    static void init() {
        // 设置连接池
        connMgr = new PoolingHttpClientConnectionManager();
        // 设置连接池大小
        connMgr.setMaxTotal(300);
        connMgr.setDefaultMaxPerRoute(20);

        RequestConfig.Builder configBuilder = RequestConfig.custom();
        // 设置连接超时
        configBuilder.setConnectTimeout(MAX_TIMEOUT);
        // 设置读取超时
        configBuilder.setSocketTimeout(MAX_TIMEOUT);
        // 设置从连接池获取连接实例的超时
        configBuilder.setConnectionRequestTimeout(MAX_TIMEOUT);
        // 在提交请求之前 测试连接是否可用
        configBuilder.setStaleConnectionCheckEnabled(true);

        requestConfig = configBuilder.build();

        httpClient = HttpClients.custom().setConnectionManager(connMgr).setDefaultRequestConfig(requestConfig).build();
    }


    private static void closeExpiredConnectionsPeriodTask(
            final int timeUnitBySecond) {
        new Thread(() -> {
            while (!Thread.currentThread().isInterrupted()) {
                try {
                    TimeUnit.SECONDS.sleep(timeUnitBySecond);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
                connMgr.closeExpiredConnections();
            }

        }).start();
    }


    /**
     * 发送 GET 请求（HTTP）,有请求头设置
     *
     * @param url       请求地址
     * @param param     请求参数
     * @param headParam 请求头参数
     * @return 请求成功返回的字符串
     */
    public static String doGet(String url, Map<String, String> param, Map<String, String> headParam) {

        String resultString = "";
        CloseableHttpResponse response = null;
        try {
            // 创建uri
            URIBuilder builder = new URIBuilder(url);
            if (param != null) {
                for (String key : param.keySet()) {
                    builder.addParameter(key, param.get(key));
                }
            }
            URI uri = builder.build();

            // 创建http GET请求
            HttpGet httpGet = new HttpGet(uri);

            //添加请求头信息
            if (headParam != null) {
                for (String key : headParam.keySet()) {
                    httpGet.setHeader(key, headParam.get(key));
                }
            }
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                // 执行http请求
                response = httpsClient.execute(httpGet);
            }else {
                // 执行请求
                response = httpClient.execute(httpGet);
            }
            // 判断返回状态是否为200
            if (response.getStatusLine().getStatusCode() == 200) {
                resultString = EntityUtils.toString(response.getEntity(), "UTF-8");
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return resultString;
    }


    /**
     * 发送 GET 请求（HTTP）,有请求参数
     *
     * @param url   请求地址
     * @param param 请求参数
     * @return 请求成功返回的字符串
     */
    public static String doGet(String url, Map<String, String> param) {

        String resultString = "";
        CloseableHttpResponse response = null;
        try {
            // 创建uri
            URIBuilder builder = new URIBuilder(url);
            if (param != null) {
                for (String key : param.keySet()) {
                    builder.addParameter(key, param.get(key));
                }
            }
            URI uri = builder.build();

            // 创建http GET请求
            HttpGet httpGet = new HttpGet(uri);
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                // 执行http请求
                response = httpsClient.execute(httpGet);
            }else {
                // 执行请求
                response = httpClient.execute(httpGet);
            }
            // 判断返回状态是否为200
            if (response.getStatusLine().getStatusCode() == 200) {
                resultString = EntityUtils.toString(response.getEntity(), "UTF-8");
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return resultString;
    }

    /**
     * 发送 GET 请求（HTTP）,无请求参数
     *
     * @param url 请求地址
     * @return 请求成功返回的字符串
     */
    public static String doGet(String url) {
        return doGet(url, null);
    }

    /**
     * 发送 POST 请求（HTTP）,有请求参数
     *
     * @param url   请求地址
     * @param param 请求参数
     * @return 请求成功返回的字符串
     **/
    public static String doPost(String url, Map<String, String> param) {
        // 创建Httpclient对象
        CloseableHttpResponse response = null;
        String resultString = "";
        try {
            // 创建Http Post请求
            HttpPost httpPost = new HttpPost(url);
            // 创建参数列表
            if (param != null) {
                List<NameValuePair> paramList = new ArrayList<>();
                for (String key : param.keySet()) {
                    paramList.add(new BasicNameValuePair(key, param.get(key)));
                }
                // 模拟表单
                UrlEncodedFormEntity entity = new UrlEncodedFormEntity(paramList, "UTF-8");
                httpPost.setEntity(entity);
            }
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                response = httpsClient.execute(httpPost);
            }else {
                // 执行http请求
                response = httpClient.execute(httpPost);
            }
            resultString = EntityUtils.toString(response.getEntity(), "UTF-8");
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        return resultString;
    }

    /**
     * 发送 POST 请求（HTTP），不带输入数据
     *
     * @param url
     * @return
     */
    public static String doPost(String url) {
        return doPost(url, null);
    }


    /**
     * 发送 POST 请求（HTTP）,有请求参数
     *
     * @param url  请求地址
     * @param json JSONObject格式的字符串
     * @return 请求成功返回的字符串
     **/
    public static String doPostJson(String url, String json) {
        // 创建Httpclient对象
        CloseableHttpResponse response = null;
        String resultString = "";
        try {
            // 创建Http Post请求
            HttpPost httpPost = new HttpPost(url);
            // 创建请求内容
            StringEntity entity = new StringEntity(json, ContentType.APPLICATION_JSON);
            httpPost.setEntity(entity);
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                response = httpsClient.execute(httpPost);
            }else {// 执行http请求
                response = httpClient.execute(httpPost);
            }
            resultString = EntityUtils.toString(response.getEntity(), "utf-8");
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return resultString;
    }

    public static String doPostJson2(String url, String json) {
        // 创建Httpclient对象
        CloseableHttpResponse response = null;
        String resultString = "";
        try {
            // 创建Http Post请求
            HttpPost httpPost = new HttpPost(url);
            // 创建请求内容
            StringEntity entity = new StringEntity(json, ContentType.APPLICATION_JSON);
            httpPost.setEntity(entity);
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                response = httpsClient.execute(httpPost);
            }else {
                // 执行http请求
                response = httpClient.execute(httpPost);
            }
            resultString = EntityUtils.toString(response.getEntity(), "utf-8");
        } catch (Exception e) {
            //性能测试，不对异常做任何处理
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                //性能测试，不对异常做任何处理
            }
        }
        return resultString;
    }

    /**
     * 发送 PUT 请求（HTTP）,有请求参数
     *
     * @param url  请求地址
     * @param json JSONObject格式的字符串
     * @return 请求成功返回的字符串
     * @author wuxiaohua
     * @date 2019/11/20 11:12
     **/
    public static String doPutJson(String url, String json) {
        // 创建Httpclient对象
        CloseableHttpResponse response = null;
        String resultString = "";
        try {

            // 创建Http Post请求
            HttpPut httpPut = new HttpPut(url);
            // 创建请求内容
            StringEntity entity = new StringEntity(json, ContentType.APPLICATION_JSON);
            httpPut.setEntity(entity);
            //判断是否是https请求
            if(url.toLowerCase().startsWith("https")){
                //创建httpClient
                CloseableHttpClient httpsClient = getIgnoeSSLClient();
                // 执行http请求
                response = httpsClient.execute(httpPut);
            }else {
                // 执行http请求
                response = httpClient.execute(httpPut);
            }
            resultString = EntityUtils.toString(response.getEntity(), "utf-8");
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return resultString;
    }

    /**
     * 获取https的client
     *
     * @return 创建成功的https客户端
     * @author liuhuan
     * @date 2022/10/24 11:12
     **/
    public static CloseableHttpClient getIgnoeSSLClient() throws Exception {
        SSLContext sslContext = SSLContexts.custom().loadTrustMaterial(null, (TrustStrategy) (x509Certificates, s) -> true).build();
        //创建httpClient
        CloseableHttpClient client = HttpClients.custom().setSSLContext(sslContext).
                setSSLHostnameVerifier(new NoopHostnameVerifier()).build();
        return client;
    }

}
